@@ -4,6 +4,7 @@ import os
 import sys
 from threading import Lock
 from typing import Optional
+from warnings import warn
 
 from .exceptions import ClientException
 
@@ -29,6 +30,12 @@ class Config:
         "extended": configparser.ExtendedInterpolation,
     }
 
+    @staticmethod
+    def _config_boolean(item):
+        if isinstance(item, bool):
+            return item
+        return item.lower() in {"1", "yes", "true", "on"}
+
     @classmethod
     def _load_config(cls, config_interpolation: Optional[str] = None):
         """Attempt to load settings from various praw.ini files."""
@@ -54,7 +61,11 @@ class Config:
 
     @property
     def short_url(self) -> str:
-        """Return the short url or raise a ClientException when not set."""
+        """Return the short url.
+
+        :raises: :class:`.ClientException` if it is not set.
+
+        """
         if self._short_url is self.CONFIG_NOT_SET:
             raise ClientException("No short domain specified.")
         return self._short_url
@@ -74,11 +85,21 @@ class Config:
         self.custom = dict(Config.CONFIG.items(site_name), **settings)
 
         self.client_id = self.client_secret = self.oauth_url = None
-        self.reddit_url = self.refresh_token = self.redirect_uri = None
+        self.reddit_url = self.redirect_uri = None
         self.password = self.user_agent = self.username = None
 
         self._initialize_attributes()
 
+        self._do_not_use_refresh_token = self._fetch_or_not_set("refresh_token")
+        if self._do_not_use_refresh_token != self.CONFIG_NOT_SET:
+            warn(
+                "The ``refresh_token`` configuration setting is deprecated and will be"
+                " removed in Async PRAW 8. Please use ``token_manager`` to manage your"
+                " refresh tokens.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+
     def _fetch(self, key):
         value = self.custom[key]
         del self.custom[key]
@@ -101,6 +122,9 @@ class Config:
 
     def _initialize_attributes(self):
         self._short_url = self._fetch_default("short_url") or self.CONFIG_NOT_SET
+        self.check_for_updates = self._config_boolean(
+            self._fetch_or_not_set("check_for_updates")
+        )
         self.kinds = {
             x: self._fetch(f"{x}_kind")
             for x in [
@@ -117,7 +141,6 @@ class Config:
             "client_id",
             "client_secret",
             "redirect_uri",
-            "refresh_token",
             "password",
             "user_agent",
             "username",
@@ -140,7 +163,7 @@ class Config:
                 setattr(self, attribute, conversion(getattr(self, attribute)))
             except ValueError:
                 raise ValueError(
-                    f"An incorrect config type was given for option {attribute}. The "
-                    f"expected type is {conversion.__name__}, but the given value is "
-                    f"{getattr(self, attribute)}."
+                    f"An incorrect config type was given for option {attribute}. The"
+                    f" expected type is {conversion.__name__}, but the given value is"
+                    f" {getattr(self, attribute)}."
                 )
