@@ -8,13 +8,13 @@ from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import asyncpraw
 
 
 class SubListing(BaseListingMixin):
     """Helper class for generating :class:`.ListingGenerator` objects."""
 
-    def __init__(self, reddit: "Reddit", base_path: str, subpath: str):
+    def __init__(self, reddit: "asyncpraw.Reddit", base_path: str, subpath: str):
         """Initialize a SubListing instance.
 
         :param reddit: An instance of :class:`.Reddit`.
@@ -35,8 +35,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     def comments(self) -> SubListing:
         r"""Provide an instance of :class:`.SubListing` for comment access.
 
-        For example, to output the first line of all new comments by
-        ``u/spez`` try:
+        For example, to output the first line of all new comments by ``u/spez`` try:
 
         .. code-block:: python
 
@@ -51,8 +50,8 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     def submissions(self) -> SubListing:
         """Provide an instance of :class:`.SubListing` for submission access.
 
-        For example, to output the title's of top 100 of all time submissions
-        for ``u/spez`` try:
+        For example, to output the title's of top 100 of all time submissions for
+        ``u/spez`` try:
 
         .. code-block:: python
 
@@ -76,6 +75,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
                 Since this function returns a :class:`.ListingGenerator` the exception
                 may not occur until sometime after this function has returned.
 
+
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
@@ -105,6 +105,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
                 Since this function returns a :class:`.ListingGenerator` the exception
                 may not occur until sometime after this function has returned.
 
+
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
@@ -134,6 +135,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
                 Since this function returns a :class:`.ListingGenerator` the exception
                 may not occur until sometime after this function has returned.
 
+
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
@@ -163,6 +165,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
                 Since this function returns a :class:`.ListingGenerator` the exception
                 may not occur until sometime after this function has returned.
 
+
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
@@ -192,6 +195,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
                 Since this function returns a :class:`.ListingGenerator` the exception
                 may not occur until sometime after this function has returned.
 
+
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
