@@ -11,7 +11,191 @@ from .submission import Submission
 from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import asyncpraw
+
+
+class CollectionModeration(AsyncPRAWBase):
+    """Class to support moderation actions on a :class:`.Collection`.
+
+    Obtain an instance via:
+
+    .. code-block:: python
+
+        subreddit = await reddit.subreddit("SUBREDDIT")
+        collection = await subreddit.collections("some_uuid")
+        collection.mod
+
+    """
+
+    def _post_fullname(self, post):
+        """Get a post's fullname.
+
+        :param post: A fullname, a Submission, a permalink, or an ID.
+
+        :returns: The fullname of the post.
+
+        """
+        if isinstance(post, Submission):
+            return post.fullname
+        elif not isinstance(post, str):
+            raise TypeError(f"Cannot get fullname from object of type {type(post)}.")
+        if post.startswith(f"{self._reddit.config.kinds['submission']}_"):
+            return post
+        try:
+            return Submission(self._reddit, url=post).fullname
+        except ClientException:
+            return Submission(self._reddit, id=post).fullname
+
+    def __init__(self, reddit: "asyncpraw.Reddit", collection_id: str):
+        """Initialize an instance of CollectionModeration.
+
+        :param collection_id: The ID of a collection.
+
+        """
+        super().__init__(reddit, _data=None)
+        self.collection_id = collection_id
+
+    async def add_post(self, submission: "asyncpraw.models.Submission"):
+        """Add a post to the collection.
+
+        :param submission: The post to add, a :class:`.Submission`, its permalink as a
+            ``str``, its fullname as a ``str``, or its ID as a ``str``.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.add_post("bgibu9")
+
+        .. seealso::
+
+            :meth:`.remove_post`
+
+        """
+        link_fullname = self._post_fullname(submission)
+
+        await self._reddit.post(
+            API_PATH["collection_add_post"],
+            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
+        )
+
+    async def delete(self):
+        """Delete this collection.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.delete()
+
+        .. seealso::
+
+            :meth:`~.SubredditCollectionsModeration.create`
+
+        """
+        await self._reddit.post(
+            API_PATH["collection_delete"],
+            data={"collection_id": self.collection_id},
+        )
+
+    async def remove_post(self, submission: "asyncpraw.models.Submission"):
+        """Remove a post from the collection.
+
+        :param submission: The post to remove, a :class:`.Submission`, its permalink as
+            a ``str``, its fullname as a ``str``, or its ID as a ``str``.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.remove_post("bgibu9")
+
+        .. seealso::
+
+            :meth:`.add_post`
+
+        """
+        link_fullname = self._post_fullname(submission)
+
+        await self._reddit.post(
+            API_PATH["collection_remove_post"],
+            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
+        )
+
+    async def reorder(self, links: List[Union[str, "asyncpraw.models.Submission"]]):
+        """Reorder posts in the collection.
+
+        :param links: A ``list`` of submissions, as :class:`.Submission`, permalink as a
+            ``str``, fullname as a ``str``, or ID as a ``str``.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            current_order = collection.link_ids
+            new_order = reversed(current_order)
+            await collection.mod.reorder(new_order)
+
+        """
+        link_ids = ",".join([self._post_fullname(post) for post in links])
+        await self._reddit.post(
+            API_PATH["collection_reorder"],
+            data={"collection_id": self.collection_id, "link_ids": link_ids},
+        )
+
+    async def update_description(self, description: str):
+        """Update the collection's description.
+
+        :param description: The new description.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.update_description("Please enjoy these links")
+
+        .. seealso::
+
+            :meth:`.update_title`
+
+        """
+        await self._reddit.post(
+            API_PATH["collection_desc"],
+            data={"collection_id": self.collection_id, "description": description},
+        )
+
+    async def update_title(self, title: str):
+        """Update the collection's title.
+
+        :param title: The new title.
+
+        Example usage:
+
+        .. code-block:: python
+
+            subreddit = await reddit.subreddit("SUBREDDIT")
+            collection = await subreddit.collections("some_uuid")
+            await collection.mod.update_title("Titley McTitleface")
+
+        .. seealso::
+
+            :meth:`.update_description`
+
+        """
+        await self._reddit.post(
+            API_PATH["collection_title"],
+            data={"collection_id": self.collection_id, "title": title},
+        )
 
 
 class Collection(RedditBase):
@@ -30,48 +214,47 @@ class Collection(RedditBase):
 
         subreddit = await reddit.subreddit("SUBREDDIT")
         collection = await subreddit.collections(
-            permalink="https://reddit.com/r/SUBREDDIT/collection/some_uuid")
+            permalink="https://reddit.com/r/SUBREDDIT/collection/some_uuid"
+        )
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor that they
-    will be the only attributes present.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor that they will be the only attributes
+    present.
 
-    ======================= ==================================================
-    Attribute               Description
-    ======================= ==================================================
-    ``author``              The :class:`.Redditor` who created the collection.
-    ``collection_id``       The UUID of the collection.
-    ``created_at_utc``      Time the collection was created, represented in
-                            `Unix Time`_.
-    ``description``         The collection description.
-    ``last_update_utc``     Time the collection was last updated, represented
-                            in `Unix Time`_.
-    ``link_ids``            A ``list`` of :class:`.Submission` fullnames.
-    ``permalink``           The collection's permalink (to view on the web).
-    ``sorted_links``        An iterable listing of the posts in
-                            this collection.
-    ``title``               The title of the collection.
-    ======================= ==================================================
+    =================== =============================================================
+    Attribute           Description
+    =================== =============================================================
+    ``author``          The :class:`.Redditor` who created the collection.
+    ``collection_id``   The UUID of the collection.
+    ``created_at_utc``  Time the collection was created, represented in `Unix Time`_.
+    ``description``     The collection description.
+    ``last_update_utc`` Time the collection was last updated, represented in `Unix
+                        Time`_.
+    ``link_ids``        A ``list`` of :class:`.Submission` fullnames.
+    ``permalink``       The collection's permalink (to view on the web).
+    ``sorted_links``    An iterable listing of the posts in this collection.
+    ``title``           The title of the collection.
+    =================== =============================================================
 
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
     """
 
     STR_FIELD = "collection_id"
 
     @cachedproperty
-    def mod(self) -> "CollectionModeration":
+    def mod(self) -> CollectionModeration:
         """Get an instance of :class:`.CollectionModeration`.
 
         Provides access to various methods, including
         :meth:`~reddit.collections.CollectionModeration.add_post`,
         :meth:`~reddit.collections.CollectionModeration.delete`,
-        :meth:`~reddit.collections.CollectionModeration.reorder`,
-        and :meth:`~reddit.collections.CollectionModeration.update_title`.
+        :meth:`~reddit.collections.CollectionModeration.reorder`, and
+        :meth:`~reddit.collections.CollectionModeration.update_title`.
 
         Example usage:
 
@@ -84,7 +267,7 @@ class Collection(RedditBase):
         """
         return CollectionModeration(self._reddit, self.collection_id)
 
-    async def subreddit(self) -> Subreddit:
+    async def subreddit(self) -> "asyncpraw.models.Subreddit":
         """Get the subreddit that this collection belongs to.
 
         For example:
@@ -101,7 +284,7 @@ class Collection(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         _data: Dict[str, Any] = None,
         collection_id: Optional[str] = None,
         permalink: Optional[str] = None,
@@ -112,6 +295,7 @@ class Collection(RedditBase):
         :param _data: Any data associated with the Collection (optional).
         :param collection_id: The ID of the Collection (optional).
         :param permalink: The permalink of the Collection (optional).
+
         """
         if (_data, collection_id, permalink).count(None) != 2:
             raise TypeError(
@@ -205,7 +389,10 @@ class Collection(RedditBase):
             collection = await subreddit.collections("some_uuid")
             await collection.follow()
 
-        .. seealso:: :meth:`~.unfollow`
+        .. seealso::
+
+            :meth:`~.unfollow`
+
         """
         await self._reddit.post(
             API_PATH["collection_follow"],
@@ -223,7 +410,10 @@ class Collection(RedditBase):
             collection = await subreddit.collections("some_uuid")
             await collection.unfollow()
 
-        .. seealso:: :meth:`~.follow`
+        .. seealso::
+
+            :meth:`~.follow`
+
         """
         await self._reddit.post(
             API_PATH["collection_follow"],
@@ -231,175 +421,61 @@ class Collection(RedditBase):
         )
 
 
-class CollectionModeration(AsyncPRAWBase):
-    """Class to support moderation actions on a :class:`.Collection`.
+class SubredditCollectionsModeration(AsyncPRAWBase):
+    """Class to represent moderator actions on a Subreddit's Collections.
 
     Obtain an instance via:
 
     .. code-block:: python
 
         subreddit = await reddit.subreddit("SUBREDDIT")
-        collection = await subreddit.collections("some_uuid")
-        collection.mod
+        subreddit.collections.mod
+
     """
 
-    def _post_fullname(self, post):
-        """Get a post's fullname.
+    def __init__(
+        self,
+        reddit: "asyncpraw.Reddit",
+        subreddit: "asyncpraw.models.Subreddit",
+        _data: Optional[Dict[str, Any]] = None,
+    ):
+        """Initialize the SubredditCollectionsModeration instance."""
+        super().__init__(reddit, _data)
+        self.subreddit = subreddit
 
-        :param post: A fullname, a Submission, a permalink, or an ID.
-        :returns: The fullname of the post.
-        """
-        if isinstance(post, Submission):
-            return post.fullname
-        elif not isinstance(post, str):
-            raise TypeError(f"Cannot get fullname from object of type {type(post)}.")
-        if post.startswith(f"{self._reddit.config.kinds['submission']}_"):
-            return post
-        try:
-            return Submission(self._reddit, url=post).fullname
-        except ClientException:
-            return Submission(self._reddit, id=post).fullname
+    async def create(self, title: str, description: str):
+        """Create a new :class:`.Collection`.
 
-    def __init__(self, reddit: "Reddit", collection_id: str):
-        """Initialize an instance of CollectionModeration.
+        The authenticated account must have appropriate moderator permissions in the
+        subreddit this collection belongs to.
 
-        :param collection_id: The ID of a collection.
-        """
-        super().__init__(reddit, _data=None)
-        self.collection_id = collection_id
+        :param title: The title of the collection, up to 300 characters.
+        :param description: The description, up to 500 characters.
 
-    async def add_post(self, submission: "Submission"):
-        """Add a post to the collection.
-
-        :param submission: The post to add, a :class:`.Submission`, its
-            permalink as a ``str``, its fullname as a ``str``, or its ID as a
-            ``str``.
+        :returns: The newly created :class:`.Collection`.
 
         Example usage:
 
         .. code-block:: python
 
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            await collection.mod.add_post("bgibu9")
+            sub = await reddit.subreddit("SUBREDDIT")
+            new_collection = await sub.collections.mod.create("Title", "desc")
+            await new_collection.mod.add_post("bgibu9")
 
-        .. seealso:: :meth:`.remove_post`
+        .. seealso::
+
+            :meth:`~CollectionModeration.delete`
 
         """
-        link_fullname = self._post_fullname(submission)
-
-        await self._reddit.post(
-            API_PATH["collection_add_post"],
-            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
-        )
-
-    async def delete(self):
-        """Delete this collection.
-
-        Example usage:
-
-        .. code-block:: python
-
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            await collection.mod.delete()
-
-        .. seealso:: :meth:`~.SubredditCollectionsModeration.create`
-
-        """
-        await self._reddit.post(
-            API_PATH["collection_delete"],
-            data={"collection_id": self.collection_id},
-        )
-
-    async def remove_post(self, submission: Submission):
-        """Remove a post from the collection.
-
-        :param submission: The post to remove, a :class:`.Submission`, its
-            permalink as a ``str``, its fullname as a ``str``, or its ID as a
-            ``str``.
-
-        Example usage:
-
-        .. code-block:: python
-
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            await collection.mod.remove_post("bgibu9")
-
-        .. seealso:: :meth:`.add_post`
-
-        """
-        link_fullname = self._post_fullname(submission)
-
-        await self._reddit.post(
-            API_PATH["collection_remove_post"],
-            data={"collection_id": self.collection_id, "link_fullname": link_fullname},
-        )
-
-    async def reorder(self, links: List[Union[str, Submission]]):
-        """Reorder posts in the collection.
-
-        :param links: A ``list`` of submissions, as :class:`.Submission`,
-            permalink as a ``str``, fullname as a ``str``, or ID as a ``str``.
-
-        Example usage:
-
-        .. code-block:: python
-
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            current_order = collection.link_ids
-            new_order = reversed(current_order)
-            await collection.mod.reorder(new_order)
-
-        """
-        link_ids = ",".join([self._post_fullname(post) for post in links])
-        await self._reddit.post(
-            API_PATH["collection_reorder"],
-            data={"collection_id": self.collection_id, "link_ids": link_ids},
-        )
-
-    async def update_description(self, description: str):
-        """Update the collection's description.
-
-        :param description: The new description.
-
-        Example usage:
-
-        .. code-block:: python
-
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            await collection.mod.update_description("Please enjoy these links")
-
-        .. seealso:: :meth:`.update_title`
-
-        """
-        await self._reddit.post(
-            API_PATH["collection_desc"],
-            data={"collection_id": self.collection_id, "description": description},
-        )
-
-    async def update_title(self, title: str):
-        """Update the collection's title.
-
-        :param title: The new title.
-
-        Example usage:
-
-        .. code-block:: python
-
-            subreddit = await reddit.subreddit("SUBREDDIT")
-            collection = await subreddit.collections("some_uuid")
-            await collection.mod.update_title("Titley McTitleface")
-
-        .. seealso:: :meth:`.update_description`
-
-        """
-        await self._reddit.post(
-            API_PATH["collection_title"],
-            data={"collection_id": self.collection_id, "title": title},
+        if not self.subreddit._fetched:
+            await self.subreddit._fetch()
+        return await self._reddit.post(
+            API_PATH["collection_create"],
+            data={
+                "sr_fullname": self.subreddit.fullname,
+                "title": title,
+                "description": description,
+            },
         )
 
 
@@ -416,7 +492,7 @@ class SubredditCollections(AsyncPRAWBase):
     """
 
     @cachedproperty
-    def mod(self) -> "SubredditCollectionsModeration":
+    def mod(self) -> SubredditCollectionsModeration:
         """Get an instance of :class:`.SubredditCollectionsModeration`.
 
         Provides :meth:`~SubredditCollectionsModeration.create`:
@@ -440,6 +516,7 @@ class SubredditCollections(AsyncPRAWBase):
         :param collection_id: The ID of a Collection (default: None).
         :param permalink: The permalink of a Collection (default: None).
         :param lazy: If True, object is loaded lazily (default: False)
+
         :returns: The specified Collection.
 
         Exactly one of ``collection_id`` and ``permalink`` is required.
@@ -460,8 +537,8 @@ class SubredditCollections(AsyncPRAWBase):
             print(collection.title)
             print(collection.description)
 
-        If you don't need the object fetched right away (e.g., to utilize a
-        class method) you can do:
+        If you don't need the object fetched right away (e.g., to utilize a class
+        method) you can do:
 
         .. code-block:: python
 
@@ -483,8 +560,8 @@ class SubredditCollections(AsyncPRAWBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
-        subreddit: "Subreddit",
+        reddit: "asyncpraw.Reddit",
+        subreddit: "asyncpraw.models.Subreddit",
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Initialize an instance of SubredditCollections."""
@@ -513,60 +590,4 @@ class SubredditCollections(AsyncPRAWBase):
             yield collection
 
 
-class SubredditCollectionsModeration(AsyncPRAWBase):
-    """Class to represent moderator actions on a Subreddit's Collections.
-
-    Obtain an instance via:
-
-    .. code-block:: python
-
-        subreddit = await reddit.subreddit("SUBREDDIT")
-        subreddit.collections.mod
-
-    """
-
-    def __init__(
-        self,
-        reddit: "Reddit",
-        subreddit: Subreddit,
-        _data: Optional[Dict[str, Any]] = None,
-    ):
-        """Initialize the SubredditCollectionsModeration instance."""
-        super().__init__(reddit, _data)
-        self.subreddit = subreddit
-
-    async def create(self, title: str, description: str):
-        """Create a new :class:`.Collection`.
-
-        The authenticated account must have appropriate moderator
-        permissions in the subreddit this collection belongs to.
-
-        :param title: The title of the collection, up to 300 characters.
-        :param description: The description, up to 500 characters.
-
-        :returns: The newly created :class:`.Collection`.
-
-        Example usage:
-
-        .. code-block:: python
-
-            sub = await reddit.subreddit("SUBREDDIT")
-            new_collection = await sub.collections.mod.create("Title", "desc")
-            await new_collection.mod.add_post("bgibu9")
-
-        .. seealso:: :meth:`~CollectionModeration.delete`
-
-        """
-        if not self.subreddit._fetched:
-            await self.subreddit._fetch()
-        return await self._reddit.post(
-            API_PATH["collection_create"],
-            data={
-                "sr_fullname": self.subreddit.fullname,
-                "title": title,
-                "description": description,
-            },
-        )
-
-
 Subreddit._subreddit_collections_class = SubredditCollections
