@@ -11,8 +11,7 @@ from .mixins import FullnameMixin
 from .redditor import Redditor
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
-    from .submission import Submission  # noqa: F401
+    from .... import asyncpraw
 
 
 class LiveContributorRelationship:
@@ -26,7 +25,7 @@ class LiveContributorRelationship:
             permissions = set(permissions)
         return ",".join(f"+{x}" for x in permissions)
 
-    def __call__(self) -> AsyncIterator[Redditor]:
+    def __call__(self) -> AsyncIterator["asyncpraw.models.Redditor"]:
         """Return a :class:`.RedditorList` for live threads' contributors.
 
         Usage:
@@ -36,6 +35,7 @@ class LiveContributorRelationship:
             thread = await reddit.live("ukaeu1ik4sw5")
             async for contributor in thread.contributor():
                 print(contributor)
+
         """
 
         async def generator():
@@ -47,14 +47,16 @@ class LiveContributorRelationship:
 
         return generator()
 
-    def __init__(self, thread: "LiveThread"):
+    def __init__(self, thread: "asyncpraw.models.LiveThread"):
         """Create a :class:`.LiveContributorRelationship` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
 
-        .. note:: This class should not be initialized directly. Instead obtain
-           an instance via: ``thread.contributor`` where ``thread`` is a
-           :class:`.LiveThread` instance.
+        .. note::
+
+            This class should not be initialized directly. Instead obtain an instance
+            via: ``thread.contributor`` where ``thread`` is a :class:`.LiveThread`
+            instance.
 
         """
         self.thread = thread
@@ -74,19 +76,20 @@ class LiveContributorRelationship:
         await self.thread._reddit.post(url)
 
     async def invite(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "asyncpraw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Invite a redditor to be a contributor of the live thread.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant. An empty list ``[]`` indicates no permissions, and when
-            not provided (``None``), indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant. An empty list
+            ``[]`` indicates no permissions, and when not provided (``None``), indicates
+            full permissions.
 
-        :raises: :class:`.RedditAPIException` if the invitation
-            already exists.
+        :raises: :class:`.RedditAPIException` if the invitation already exists.
 
         Usage:
 
@@ -98,8 +101,10 @@ class LiveContributorRelationship:
             # "manage" and "settings" permissions
             await thread.contributor.invite(redditor, ["manage", "settings"])
 
-        .. seealso:: :meth:`.LiveContributorRelationship.remove_invite` to
-            remove the invite for redditor.
+        .. seealso::
+
+            :meth:`.LiveContributorRelationship.remove_invite` to remove the invite for
+            redditor.
 
         """
         url = API_PATH["live_invite"].format(id=self.thread.id)
@@ -124,7 +129,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_leave"].format(id=self.thread.id)
         await self.thread._reddit.post(url)
 
-    async def remove(self, redditor: Union[str, Redditor]):
+    async def remove(self, redditor: Union[str, "asyncpraw.models.Redditor"]):
         """Remove the redditor from the live thread contributors.
 
         :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
@@ -148,7 +153,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_remove_contrib"].format(id=self.thread.id)
         await self.thread._reddit.post(url, data=data)
 
-    async def remove_invite(self, redditor: Union[str, Redditor]):
+    async def remove_invite(self, redditor: Union[str, "asyncpraw.models.Redditor"]):
         """Remove the invite for redditor.
 
         :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
@@ -165,7 +170,8 @@ class LiveContributorRelationship:
 
         .. seealso::
 
-             :meth:`.LiveContributorRelationship.invite` to invite a redditor to be a contributor of the live thread.
+            :meth:`.LiveContributorRelationship.invite` to invite a redditor to be a
+            contributor of the live thread.
 
         """
         if isinstance(redditor, Redditor):
@@ -177,17 +183,18 @@ class LiveContributorRelationship:
         await self.thread._reddit.post(url, data=data)
 
     async def update(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "asyncpraw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Update the contributor permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant (other permissions are removed). An empty list ``[]``
-            indicates no permissions, and when not provided (``None``),
-            indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant (other
+            permissions are removed). An empty list ``[]`` indicates no permissions, and
+            when not provided (``None``), indicates full permissions.
 
         For example, to grant all permissions to the contributor, try:
 
@@ -196,8 +203,8 @@ class LiveContributorRelationship:
             thread = await reddit.live("ukaeu1ik4sw5")
             await thread.contributor.update("spez")
 
-        To grant ``"access"`` and ``"edit"`` permissions (and to
-        remove other permissions), try:
+        To grant ``"access"`` and ``"edit"`` permissions (and to remove other
+        permissions), try:
 
         .. code-block:: python
 
@@ -219,17 +226,18 @@ class LiveContributorRelationship:
         await self.thread._reddit.post(url, data=data)
 
     async def update_invite(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "asyncpraw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Update the contributor invite permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant (other permissions are removed). An empty list ``[]``
-            indicates no permissions, and when not provided (``None``),
-            indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant (other
+            permissions are removed). An empty list ``[]`` indicates no permissions, and
+            when not provided (``None``), indicates full permissions.
 
         For example, to set all permissions to the invitation, try:
 
@@ -238,8 +246,8 @@ class LiveContributorRelationship:
             thread = await reddit.live("ukaeu1ik4sw5")
             await thread.contributor.update_invite("spez")
 
-        To set "access" and "edit" permissions (and to remove other
-        permissions) to the invitation, try:
+        To set "access" and "edit" permissions (and to remove other permissions) to the
+        invitation, try:
 
         .. code-block:: python
 
@@ -266,31 +274,30 @@ class LiveThread(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
-    Attribute               Description
-    ======================= ===================================================
-    ``created_utc``         The creation time of the live thread, in `Unix
-                            Time`_.
-    ``description``         Description of the live thread, as Markdown.
-    ``description_html``    Description of the live thread, as HTML.
-    ``id``                  The ID of the live thread.
-    ``nsfw``                A ``bool`` representing whether or not the live
-                            thread is marked as NSFW.
-    ======================= ===================================================
+    ==================== =========================================================
+    Attribute            Description
+    ==================== =========================================================
+    ``created_utc``      The creation time of the live thread, in `Unix Time`_.
+    ``description``      Description of the live thread, as Markdown.
+    ``description_html`` Description of the live thread, as HTML.
+    ``id``               The ID of the live thread.
+    ``nsfw``             A ``bool`` representing whether or not the live thread is
+                         marked as NSFW.
+    ==================== =========================================================
+
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
 
     STR_FIELD = "id"
 
     @cachedproperty
-    def contrib(self) -> "LiveThreadContribution":
+    def contrib(self) -> "asyncpraw.models.reddit.live.LiveThreadContribution":
         """Provide an instance of :class:`.LiveThreadContribution`.
 
         Usage:
@@ -304,13 +311,12 @@ class LiveThread(RedditBase):
         return LiveThreadContribution(self)
 
     @cachedproperty
-    def contributor(self) -> LiveContributorRelationship:
+    def contributor(self) -> "asyncpraw.models.reddit.live.LiveContributorRelationship":
         """Provide an instance of :class:`.LiveContributorRelationship`.
 
-        You can call the instance to get a list of contributors which is
-        represented as :class:`.RedditorList` instance consists of
-        :class:`.Redditor` instances. Those Redditor instances have
-        ``permissions`` attributes as contributors:
+        You can call the instance to get a list of contributors which is represented as
+        :class:`.RedditorList` instance consists of :class:`.Redditor` instances. Those
+        Redditor instances have ``permissions`` attributes as contributors:
 
         .. code-block:: python
 
@@ -323,21 +329,20 @@ class LiveThread(RedditBase):
         return LiveContributorRelationship(self)
 
     @cachedproperty
-    def stream(self) -> "LiveThreadStream":
+    def stream(self) -> "asyncpraw.models.reddit.live.LiveThreadStream":
         """Provide an instance of :class:`.LiveThreadStream`.
 
-        Streams are used to indefinitely retrieve new updates made to a
-        live thread, like:
+        Streams are used to indefinitely retrieve new updates made to a live thread,
+        like:
 
         .. code-block:: python
 
             for live_update in reddit.live("ta535s1hq2je").stream.updates():
                 print(live_update.body)
 
-        Updates are yielded oldest first as :class:`.LiveUpdate`. Up to 100
-        historical updates will initially be returned.
-        To only retrieve new updates starting from when the stream is
-        created, pass ``skip_existing=True``:
+        Updates are yielded oldest first as :class:`.LiveUpdate`. Up to 100 historical
+        updates will initially be returned. To only retrieve new updates starting from
+        when the stream is created, pass ``skip_existing=True``:
 
         .. code-block:: python
 
@@ -348,19 +353,25 @@ class LiveThread(RedditBase):
         """
         return LiveThreadStream(self)
 
-    def __eq__(self, other: Union[str, "LiveThread"]) -> bool:
+    def __eq__(self, other: Union[str, "asyncpraw.models.LiveThread"]) -> bool:
         """Return whether the other instance equals the current.
 
-        .. note:: This comparison is case sensitive.
+        .. note::
+
+            This comparison is case sensitive.
+
         """
         if isinstance(other, str):
             return other == str(self)
         return isinstance(other, self.__class__) and str(self) == str(other)
 
-    async def get_update(self, update_id: str, lazy: bool = False) -> "LiveUpdate":
+    async def get_update(
+        self, update_id: str, lazy: bool = False
+    ) -> "asyncpraw.models.LiveUpdate":
         """Return a :class:`.LiveUpdate` instance.
 
-        :param update_id: A live update ID, e.g., ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
+        :param update_id: A live update ID, e.g.,
+            ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
         :param lazy: If True, object is loaded lazily (default: False).
 
         Usage:
@@ -369,18 +380,19 @@ class LiveThread(RedditBase):
 
             thread = await reddit.live("ukaeu1ik4sw5")
             update = await thread.get_update("7827987a-c998-11e4-a0b9-22000b6a88d2")
-            update.thread     # LiveThread(id="ukaeu1ik4sw5")
-            update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
-            update.author     # "umbrae"
+            update.thread  # LiveThread(id="ukaeu1ik4sw5")
+            update.id  # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+            update.author  # "umbrae"
 
-        If you don't need the object fetched right away (e.g., to utilize a
-        class method) you can do:
+        If you don't need the object fetched right away (e.g., to utilize a class
+        method) you can do:
 
         .. code-block:: python
 
             thread = await reddit.live("ukaeu1ik4sw5")
             update = await thread.get_update("7827987a-c998-11e4-a0b9-22000b6a88d2", lazy=True)
             update.contrib  # LiveUpdateContribution instance
+
         """
         update = LiveUpdate(self._reddit, self.id, update_id)
         if not lazy:
@@ -393,7 +405,7 @@ class LiveThread(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,  # pylint: disable=redefined-builtin
     ):
@@ -401,6 +413,7 @@ class LiveThread(RedditBase):
 
         :param reddit: An instance of :class:`.Reddit`.
         :param id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``
+
         """
         if (id, _data).count(None) != 1:
             raise TypeError("Either `id` or `_data` must be provided.")
@@ -425,13 +438,14 @@ class LiveThread(RedditBase):
 
     def discussions(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator["Submission"]:
+    ) -> AsyncIterator["asyncpraw.models.Submission"]:
         """Get submissions linking to the thread.
 
-        :param generator_kwargs: keyword arguments passed to
-            :class:`.ListingGenerator` constructor.
-        :returns: A :class:`.ListingGenerator` object which yields
-            :class:`.Submission` object.
+        :param generator_kwargs: keyword arguments passed to :class:`.ListingGenerator`
+            constructor.
+
+        :returns: A :class:`.ListingGenerator` object which yields :class:`.Submission`
+            object.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -452,8 +466,7 @@ class LiveThread(RedditBase):
         """Report the thread violating the Reddit rules.
 
         :param type: One of ``"spam"``, ``"vote-manipulation"``,
-            ``"personal-information"``, ``"sexualizing-minors"``,
-            ``"site-breaking"``.
+            ``"personal-information"``, ``"sexualizing-minors"``, ``"site-breaking"``.
 
         Usage:
 
@@ -468,13 +481,14 @@ class LiveThread(RedditBase):
 
     async def updates(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator["LiveUpdate"]:
+    ) -> AsyncIterator["asyncpraw.models.LiveUpdate"]:
         """Return a :class:`.ListingGenerator` yields :class:`.LiveUpdate` s.
 
-        :param generator_kwargs: keyword arguments passed to
-            :class:`.ListingGenerator` constructor.
-        :returns: A :class:`.ListingGenerator` object which yields
-            :class:`.LiveUpdate` object.
+        :param generator_kwargs: keyword arguments passed to :class:`.ListingGenerator`
+            constructor.
+
+        :returns: A :class:`.ListingGenerator` object which yields :class:`.LiveUpdate`
+            object.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -498,13 +512,13 @@ class LiveThread(RedditBase):
 class LiveThreadContribution:
     """Provides a set of contribution functions to a LiveThread."""
 
-    def __init__(self, thread: LiveThread):
+    def __init__(self, thread: "asyncpraw.models.LiveThread"):
         """Create an instance of :class:`.LiveThreadContribution`.
 
         :param thread: An instance of :class:`.LiveThread`.
 
-        This instance can be retrieved through ``thread.contrib``
-        where thread is a :class:`.LiveThread` instance. E.g.,
+        This instance can be retrieved through ``thread.contrib`` where thread is a
+        :class:`.LiveThread` instance. E.g.,
 
         .. code-block:: python
 
@@ -555,19 +569,18 @@ class LiveThreadContribution:
         """Update settings of the live thread.
 
         :param title: (Optional) The title of the live thread (default: None).
-        :param description: (Optional) The live thread's description
+        :param description: (Optional) The live thread's description (default: None).
+        :param nsfw: (Optional) Indicate whether this thread is not safe for work
             (default: None).
-        :param nsfw: (Optional) Indicate whether this thread is not safe for
-            work (default: None).
-        :param resources: (Optional) Markdown formatted information that is
-            useful for the live thread (default: None).
+        :param resources: (Optional) Markdown formatted information that is useful for
+            the live thread (default: None).
 
         Does nothing if no arguments are provided.
 
         Each setting will maintain its current value if ``None`` is specified.
 
-        Additional keyword arguments can be provided to handle new settings as
-        Reddit introduces them.
+        Additional keyword arguments can be provided to handle new settings as Reddit
+        introduces them.
 
         Usage:
 
@@ -578,8 +591,8 @@ class LiveThreadContribution:
             # update `title` and `nsfw`
             updated_thread = await thread.contrib.update(title=new_title, nsfw=True)
 
-        If Reddit introduces new settings, you must specify ``None`` for the
-        setting you want to maintain:
+        If Reddit introduces new settings, you must specify ``None`` for the setting you
+        want to maintain:
 
         .. code-block:: python
 
@@ -621,29 +634,32 @@ class LiveThreadStream:
 
     """
 
-    def __init__(self, live_thread: LiveThread):
+    def __init__(self, live_thread: "asyncpraw.models.LiveThread"):
         """Create a LiveThreadStream instance.
 
         :param live_thread: The live thread associated with the stream.
+
         """
         self.live_thread = live_thread
 
-    def updates(self, **stream_options: Dict[str, Any]) -> AsyncIterator["LiveUpdate"]:
+    def updates(
+        self, **stream_options: Dict[str, Any]
+    ) -> AsyncIterator["asyncpraw.models.LiveUpdate"]:
         """Yield new updates to the live thread as they become available.
 
-        :param skip_existing: Set to ``True`` to only fetch items created
-            after the stream (default: ``False``).
+        :param skip_existing: Set to ``True`` to only fetch items created after the
+            stream (default: ``False``).
 
         As with :meth:`.LiveThread.updates()`, updates are yielded as
         :class:`.LiveUpdate`.
 
-        Updates are yielded oldest first. Up to 100 historical updates will
-        initially be returned.
+        Updates are yielded oldest first. Up to 100 historical updates will initially be
+        returned.
 
         Keyword arguments are passed to :func:`.stream_generator`.
 
-        For example, to retrieve all new updates made to the
-        ``"ta535s1hq2je"`` live thread, try:
+        For example, to retrieve all new updates made to the ``"ta535s1hq2je"`` live
+        thread, try:
 
         .. code-block:: python
 
@@ -651,8 +667,8 @@ class LiveThreadStream:
             async for live_update in live.stream.updates():
                 print(live_update.body)
 
-        To only retrieve new updates starting from when the stream is
-        created, pass ``skip_existing=True``:
+        To only retrieve new updates starting from when the stream is created, pass
+        ``skip_existing=True``:
 
         .. code-block:: python
 
@@ -669,31 +685,31 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
-    Attribute               Description
-    ======================= ===================================================
-    ``author``              The :class:`.Redditor` who made the update.
-    ``body``                Body of the update, as Markdown.
-    ``body_html``           Body of the update, as HTML.
-    ``created_utc``         The time the update was created, as `Unix Time`_.
-    ``stricken``            A ``bool`` representing whether or not the update
-                            was stricken (see :meth:`.strike`).
-    ======================= ===================================================
+    =============== ===================================================================
+    Attribute       Description
+    =============== ===================================================================
+    ``author``      The :class:`.Redditor` who made the update.
+    ``body``        Body of the update, as Markdown.
+    ``body_html``   Body of the update, as HTML.
+    ``created_utc`` The time the update was created, as `Unix Time`_.
+    ``stricken``    A ``bool`` representing whether or not the update was stricken (see
+                    :meth:`.strike`).
+    =============== ===================================================================
+
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
 
     STR_FIELD = "id"
     _kind = "LiveUpdate"
 
     @cachedproperty
-    def contrib(self) -> "LiveUpdateContribution":
+    def contrib(self) -> "asyncpraw.models.reddit.live.LiveUpdateContribution":
         """Provide an instance of :class:`.LiveUpdateContribution`.
 
         Usage:
@@ -714,7 +730,7 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         thread_id: Optional[str] = None,
         update_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -725,7 +741,8 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
         :param reddit: An instance of :class:`.Reddit`.
         :param thread_id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``.
-        :param update_id: A live update ID, e.g., ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
+        :param update_id: A live update ID, e.g.,
+            ``"7827987a-c998-11e4-a0b9-22000b6a88d2"``.
 
         Usage:
 
@@ -733,9 +750,10 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
             update = LiveUpdate(reddit, "ukaeu1ik4sw5", "7827987a-c998-11e4-a0b9-22000b6a88d2")
             await update.load()
-            update.thread     # LiveThread(id="ukaeu1ik4sw5")
-            update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
-            update.author     # "umbrae"
+            update.thread  # LiveThread(id="ukaeu1ik4sw5")
+            update.id  # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+            update.author  # "umbrae"
+
         """
         if _data is not None:
             # Since _data (part of JSON returned from reddit) have no thread ID,
@@ -768,13 +786,13 @@ class LiveUpdate(FullnameMixin, RedditBase):
 class LiveUpdateContribution:
     """Provides a set of contribution functions to LiveUpdate."""
 
-    def __init__(self, update: LiveUpdate):
+    def __init__(self, update: "asyncpraw.models.LiveUpdate"):
         """Create an instance of :class:`.LiveUpdateContribution`.
 
         :param update: An instance of :class:`.LiveUpdate`.
 
-        This instance can be retrieved through ``update.contrib``
-        where update is a :class:`.LiveUpdate` instance. E.g.,
+        This instance can be retrieved through ``update.contrib`` where update is a
+        :class:`.LiveUpdate` instance. E.g.,
 
         .. code-block:: python
 
@@ -816,8 +834,8 @@ class LiveUpdateContribution:
 
         .. note::
 
-            Accessing lazy attributes on updates (includes ``update.stricken``)
-            may raise :py:class:`AttributeError`. See :class:`.LiveUpdate` for details.
+            Accessing lazy attributes on updates (includes ``update.stricken``) may
+            raise :py:class:`AttributeError`. See :class:`.LiveUpdate` for details.
 
         """
         url = API_PATH["live_strike"].format(id=self.update.thread.id)
