@@ -9,18 +9,20 @@ class ReplyableMixin:
         """Reply to the object.
 
         :param body: The Markdown formatted content for a comment.
-        :returns: A :class:`~.Comment` object for the newly created
-            comment or ``None`` if Reddit doesn't provide one.
 
-        A ``None`` value can be returned if the target is a comment or
-        submission in a quarantined subreddit and the authenticated user
-        has not opt-ed in to viewing the content. When this happens the
-        comment will be successfully created on Reddit and can be retried
-        by drawing the comment from the user's comment history.
+        :returns: A :class:`~.Comment` object for the newly created comment or ``None``
+            if Reddit doesn't provide one.
 
-        .. note:: Some items, such as locked submissions/comments or
-            non-replyable messages will throw
-            ``asyncprawcore.exceptions.Forbidden`` when attempting to reply
+        A ``None`` value can be returned if the target is a comment or submission in a
+        quarantined subreddit and the authenticated user has not opt-ed in to viewing
+        the content. When this happens the comment will be successfully created on
+        Reddit and can be retried by drawing the comment from the user's comment
+        history.
+
+        .. note::
+
+            Some items, such as locked submissions/comments or non-replyable messages
+            will throw ``asyncprawcore.exceptions.Forbidden`` when attempting to reply
             to them.
 
         Example usage:
