@@ -13,11 +13,13 @@ class VotableMixin:
     async def clear_vote(self):
         """Clear the authenticated user's vote on the object.
 
-        .. note:: Votes must be cast by humans. That is, API clients proxying a
-           human's action one-for-one are OK, but bots deciding how to vote on
-           content or amplifying a human's vote are not. See the reddit rules
-           for more details on what constitutes vote cheating. [`Ref
-           <https://www.reddit.com/dev/api#POST_api_vote>`_]
+        .. note::
+
+            Votes must be cast by humans. That is, API clients proxying a human's action
+            one-for-one are OK, but bots deciding how to vote on content or amplifying a
+            human's vote are not. See the reddit rules for more details on what
+            constitutes vote cheating. [`Ref
+            <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
@@ -35,11 +37,13 @@ class VotableMixin:
     async def downvote(self):
         """Downvote the object.
 
-        .. note:: Votes must be cast by humans. That is, API clients proxying a
-           human's action one-for-one are OK, but bots deciding how to vote on
-           content or amplifying a human's vote are not. See the reddit rules
-           for more details on what constitutes vote cheating. [`Ref
-           <https://www.reddit.com/dev/api#POST_api_vote>`_]
+        .. note::
+
+            Votes must be cast by humans. That is, API clients proxying a human's action
+            one-for-one are OK, but bots deciding how to vote on content or amplifying a
+            human's vote are not. See the reddit rules for more details on what
+            constitutes vote cheating. [`Ref
+            <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
@@ -51,7 +55,9 @@ class VotableMixin:
             comment = await reddit.comment(id="dxolpyc", lazy=True)
             await comment.downvote()
 
-        .. seealso:: :meth:`~.upvote`
+        .. seealso::
+
+            :meth:`~.upvote`
 
         """
         await self._vote(direction=-1)
@@ -59,11 +65,13 @@ class VotableMixin:
     async def upvote(self):
         """Upvote the object.
 
-        .. note:: Votes must be cast by humans. That is, API clients proxying a
-           human's action one-for-one are OK, but bots deciding how to vote on
-           content or amplifying a human's vote are not. See the reddit rules
-           for more details on what constitutes vote cheating. [`Ref
-           <https://www.reddit.com/dev/api#POST_api_vote>`_]
+        .. note::
+
+            Votes must be cast by humans. That is, API clients proxying a human's action
+            one-for-one are OK, but bots deciding how to vote on content or amplifying a
+            human's vote are not. See the reddit rules for more details on what
+            constitutes vote cheating. [`Ref
+            <https://www.reddit.com/dev/api#POST_api_vote>`_]
 
         Example usage:
 
@@ -75,7 +83,9 @@ class VotableMixin:
             comment = await reddit.comment(id="dxolpyc", lazy=True)
             await comment.upvote()
 
-        .. seealso:: :meth:`~.downvote`
+        .. seealso::
+
+            :meth:`~.downvote`
 
         """
         await self._vote(direction=1)
