@@ -6,7 +6,7 @@ from ...util import snake_case_keys
 from .base import RedditBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import asyncpraw
 
 
 class ModmailConversation(RedditBase):
@@ -14,44 +14,39 @@ class ModmailConversation(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
-    Attribute               Description
-    ======================= ===================================================
-    ``authors``             Provides an ordered list of :class:`.Redditor`
-                            instances. The authors of each message in the
-                            modmail conversation.
-    ``id``                  The ID of the ModmailConversation.
-    ``is_highlighted``      Whether or not the ModmailConversation is
-                            highlighted.
-    ``is_internal``         Whether or not the ModmailConversation is a private
-                            mod conversation.
-    ``last_mod_update``     Time of the last mod message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
-    ``last_updated``        Time of the last message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
-    ``last_user_update``    Time of the last user message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
-    ``num_messages``        The number of messages in the ModmailConversation.
-    ``obj_ids``             Provides a list of dictionaries representing
-                            mod actions on the ModmailConversation. Each dict
-                            contains attributes of "key" and "id". The key can
-                            be either "messages" or "ModAction". ModAction
-                            represents archiving/highlighting etc.
-    ``owner``               Provides an instance of :class:`.Subreddit`. The
-                            subreddit that the ModmailConversation belongs to.
-    ``participant``         Provides an instance of :class:`.Redditor`. The
-                            participating user in the ModmailConversation.
-    ``subject``             The subject of the ModmailConversation.
-    ======================= ===================================================
+    ==================== ===============================================================
+    Attribute            Description
+    ==================== ===============================================================
+    ``authors``          Provides an ordered list of :class:`.Redditor` instances. The
+                         authors of each message in the modmail conversation.
+    ``id``               The ID of the ModmailConversation.
+    ``is_highlighted``   Whether or not the ModmailConversation is highlighted.
+    ``is_internal``      Whether or not the ModmailConversation is a private mod
+                         conversation.
+    ``last_mod_update``  Time of the last mod message reply, represented in the `ISO
+                         8601`_ standard with timezone.
+    ``last_updated``     Time of the last message reply, represented in the `ISO 8601`_
+                         standard with timezone.
+    ``last_user_update`` Time of the last user message reply, represented in the `ISO
+                         8601`_ standard with timezone.
+    ``num_messages``     The number of messages in the ModmailConversation.
+    ``obj_ids``          Provides a list of dictionaries representing mod actions on the
+                         ModmailConversation. Each dict contains attributes of "key" and
+                         "id". The key can be either "messages" or "ModAction".
+                         ModAction represents archiving/highlighting etc.
+    ``owner``            Provides an instance of :class:`.Subreddit`. The subreddit that
+                         the ModmailConversation belongs to.
+    ``participant``      Provides an instance of :class:`.Redditor`. The participating
+                         user in the ModmailConversation.
+    ``subject``          The subject of the ModmailConversation.
+    ==================== ===============================================================
 
-
-    .. _ISO 8601: https://en.wikipedia.org/wiki/ISO_8601
+    .. _iso 8601: https://en.wikipedia.org/wiki/ISO_8601
 
     """
 
@@ -92,15 +87,15 @@ class ModmailConversation(RedditBase):
     def parse(  # pylint: disable=arguments-differ
         cls,
         data: Dict[str, Any],
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         convert_objects: bool = True,
     ):
         """Return an instance of ModmailConversation from ``data``.
 
         :param data: The structured data.
         :param reddit: An instance of :class:`.Reddit`.
-        :param convert_objects: If True, convert message and mod action data
-            into objects (default: True).
+        :param convert_objects: If True, convert message and mod action data into
+            objects (default: True).
 
         """
         conversation = data["conversation"]
@@ -123,15 +118,14 @@ class ModmailConversation(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         mark_read: bool = False,
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the ModmailConversation object.
 
-        :param mark_read: If True, conversation is marked as read
-            (default: False).
+        :param mark_read: If True, conversation is marked as read (default: False).
 
         """
         if bool(id) == bool(_data):
@@ -213,7 +207,6 @@ class ModmailConversation(RedditBase):
             conversation = await subreddit.modmail("2gmz")
             await conversation.mute(7)
 
-
         """
         if num_days != 3:  # no need to pass params if it's the default
             params = {"num_hours": num_days * 24}
@@ -228,8 +221,8 @@ class ModmailConversation(RedditBase):
     ):  # noqa: D207, D301
         """Mark the conversation(s) as read.
 
-        :param other_conversations: A list of other conversations to mark
-            (default: None).
+        :param other_conversations: A list of other conversations to mark (default:
+            None).
 
         For example, to mark the conversation as read along with other recent
         conversations from the same user:
@@ -250,12 +243,12 @@ class ModmailConversation(RedditBase):
         """Reply to the conversation.
 
         :param body: The Markdown formatted content for a message.
-        :param author_hidden: When True, author is hidden from non-moderators
-            (default: False).
-        :param internal: When True, message is a private moderator note,
-            hidden from non-moderators (default: False).
-        :returns: A :class:`~.ModmailMessage` object for the newly created
-            message.
+        :param author_hidden: When True, author is hidden from non-moderators (default:
+            False).
+        :param internal: When True, message is a private moderator note, hidden from
+            non-moderators (default: False).
+
+        :returns: A :class:`~.ModmailMessage` object for the newly created message.
 
         For example, to reply to the non-mod user while hiding your username:
 
@@ -333,8 +326,8 @@ class ModmailConversation(RedditBase):
     ):  # noqa: D207, D301
         """Mark the conversation(s) as unread.
 
-        :param other_conversations: A list of other conversations to mark
-            (default: None).
+        :param other_conversations: A list of other conversations to mark (default:
+            None).
 
         For example, to mark the conversation as unread along with other recent
         conversations from the same user:
@@ -343,8 +336,7 @@ class ModmailConversation(RedditBase):
 
             subreddit = await reddit.subreddit("redditdev")
             conversation = await subreddit.modmail.conversation("2gmz")
-            await conversation.unread(\
-other_conversations=conversation.user.recent_convos)
+            await conversation.unread(other_conversations=conversation.user.recent_convos)
 
         """
         data = {"conversationIds": self._build_conversation_list(other_conversations)}
