@@ -7,8 +7,7 @@ from ...exceptions import ClientException
 from .base import RedditBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
-    from .subreddit import Subreddit
+    from .... import asyncpraw
 
 
 class RemovalReason(RedditBase):
@@ -16,19 +15,19 @@ class RemovalReason(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
+
+    =========== ==================================
+    Attribute   Description
+    =========== ==================================
+    ``id``      The id of the removal reason.
+    ``message`` The message of the removal reason.
+    ``title``   The title of the removal reason.
+    =========== ==================================
 
-    ======================= ===================================================
-    Attribute               Description
-    ======================= ===================================================
-    ``id``                  The id of the removal reason.
-    ``message``             The message of the removal reason.
-    ``title``               The title of the removal reason.
-    ======================= ===================================================
     """
 
     STR_FIELD = "id"
@@ -38,8 +37,9 @@ class RemovalReason(RedditBase):
         """Reason id param is deprecated. Warns if it's used.
 
         :param reason_id_value: The value passed as parameter ``reason_id``.
-        :param id_value: Returns the actual value of parameter ``id`` is
-            parameter ``reason_id`` is not used.
+        :param id_value: Returns the actual value of parameter ``id`` is parameter
+            ``reason_id`` is not used.
+
         """
         if reason_id_value is not None:
             warn(
@@ -65,8 +65,8 @@ class RemovalReason(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
-        subreddit: "Subreddit",
+        reddit: "asyncpraw.Reddit",
+        subreddit: "asyncpraw.models.Subreddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         reason_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -76,9 +76,9 @@ class RemovalReason(RedditBase):
         :param reddit: An instance of :class:`.Reddit`.
         :param subreddit: An instance of :class:`.Subreddit`.
         :param id: The id of the removal reason.
-        :param reason_id: (Deprecated) The original name of the ``id``
-            parameter. Used for backwards compatibility. This parameter should
-            not be used.
+        :param reason_id: (Deprecated) The original name of the ``id`` parameter. Used
+            for backwards compatibility. This parameter should not be used.
+
         """
         id = self._warn_reason_id(reason_id, id)
         if (id, _data).count(None) != 1:
@@ -117,7 +117,9 @@ class RemovalReason(RedditBase):
     async def update(self, message: Optional[str] = None, title: Optional[str] = None):
         """Update the removal reason from this subreddit.
 
-        .. note:: Existing values will be used for any unspecified arguments.
+        .. note::
+
+            Existing values will be used for any unspecified arguments.
 
         :param message: The removal reason's new message.
         :param title: The removal reason's new title.
@@ -159,14 +161,16 @@ class SubredditRemovalReasons:
             reason = await subreddit.mod.removal_reasons.get_reason(reason_id)
             print(reason)
 
-        You can also use indices to get a numbered removal reason. Since Python
-        uses 0-indexing, the first removal reason is index 0, and so on.
+        You can also use indices to get a numbered removal reason. Since Python uses
+        0-indexing, the first removal reason is index 0, and so on.
 
-        .. note:: Both negative indices and slices can be used to interact with
-            the removal reasons.
+        .. note::
 
-        :raises: :py:class:`IndexError` if a removal reason of a specific
-            number does not exist.
+            Both negative indices and slices can be used to interact with the removal
+            reasons.
+
+        :raises: :py:class:`IndexError` if a removal reason of a specific number does
+            not exist.
 
         For example, to get the second removal reason of the subreddit ``"NAME"``:
 
@@ -184,8 +188,8 @@ class SubredditRemovalReasons:
             for reason in reasons:
                 print(reason)
 
-        If you don't need the object fetched right away (e.g., to utilize a
-        class method) you can do:
+        If you don't need the object fetched right away (e.g., to utilize a class
+        method) you can do:
 
         .. code-block:: python
 
@@ -204,7 +208,7 @@ class SubredditRemovalReasons:
             await reason._fetch()
         return reason
 
-    def __init__(self, subreddit: "Subreddit"):
+    def __init__(self, subreddit: "asyncpraw.models.Subreddit"):
         """Create a SubredditRemovalReasons instance.
 
         :param subreddit: The subreddit whose removal reasons to work with.
@@ -216,8 +220,7 @@ class SubredditRemovalReasons:
     async def __aiter__(self) -> AsyncIterator[RemovalReason]:
         """Return a list of Removal Reasons for the subreddit.
 
-        This method is used to discover all removal reasons for a
-        subreddit:
+        This method is used to discover all removal reasons for a subreddit:
 
         .. code-block:: python
 
@@ -233,6 +236,7 @@ class SubredditRemovalReasons:
         """Get a list of Removal Reason objects.
 
         :returns: A list of instances of :class:`.RemovalReason`.
+
         """
         response = await self._reddit.get(
             API_PATH["removal_reasons_list"].format(subreddit=self.subreddit)
@@ -247,6 +251,7 @@ class SubredditRemovalReasons:
 
         :param message: The message associated with the removal reason.
         :param title: The title of the removal reason
+
         :returns: The RemovalReason added.
 
         The message will be prepended with `Hi u/username,` automatically.
