@@ -9,8 +9,7 @@ from ...util.cache import cachedproperty
 from .base import RedditBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
-    from .subreddit import Subreddit
+    from .... import asyncpraw
 
 
 class Rule(RedditBase):
@@ -18,38 +17,34 @@ class Rule(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily comprehensive.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily comprehensive.
 
-    ======================= ===================================================
-    Attribute               Description
-    ======================= ===================================================
-    ``created_utc``         Time the rule was created, represented in
-                            `Unix Time`_.
-    ``description``         The description of the rule, if provided, otherwise
-                            a blank string.
-    ``kind``                The kind of rule. Can be ``"link"``, ``comment"``,
-                            or ``"all"``.
-    ``priority``            Represents where the rule is ranked. For example,
-                            the first rule is at priority ``0``. Serves as an
-                            index number on the list of rules.
-    ``short_name``          The name of the rule.
-    ``violation_reason``    The reason that is displayed on the report menu for
-                            the rule.
-    ======================= ===================================================
+    ==================== =============================================================
+    Attribute            Description
+    ==================== =============================================================
+    ``created_utc``      Time the rule was created, represented in `Unix Time`_.
+    ``description``      The description of the rule, if provided, otherwise a blank
+                         string.
+    ``kind``             The kind of rule. Can be ``"link"``, ``comment"``, or
+                         ``"all"``.
+    ``priority``         Represents where the rule is ranked. For example, the first
+                         rule is at priority ``0``. Serves as an index number on the
+                         list of rules.
+    ``short_name``       The name of the rule.
+    ``violation_reason`` The reason that is displayed on the report menu for the rule.
+    ==================== =============================================================
 
-
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
     """
 
     STR_FIELD = "short_name"
 
     @cachedproperty
-    def mod(self) -> "RuleModeration":
+    def mod(self) -> "asyncpraw.models.reddit.rules.RuleModeration":
         """Contain methods used to moderate rules.
 
         To delete ``"No spam"`` from the subreddit ``"NAME"`` try:
@@ -73,8 +68,8 @@ class Rule(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
-        subreddit: Optional["Subreddit"] = None,
+        reddit: "asyncpraw.Reddit",
+        subreddit: Optional["asyncpraw.models.Subreddit"] = None,
         short_name: Optional[str] = None,
         _data: Optional[Dict[str, str]] = None,
     ):
@@ -120,17 +115,16 @@ class SubredditRules:
         async for rule in subreddit.rules:
             print(rule)
 
-    Moderators can also add rules to the subreddit. For example, to make
-    a rule called ``"No spam"`` in the subreddit ``"NAME"``:
+    Moderators can also add rules to the subreddit. For example, to make a rule called
+    ``"No spam"`` in the subreddit ``"NAME"``:
 
     .. code-block:: python
 
         subreddit = await reddit.subreddit("NAME")
         await subreddit.rules.mod.add(
-            short_name="No spam",
-            kind="all",
-            description="Do not spam. Spam bad"
+            short_name="No spam", kind="all", description="Do not spam. Spam bad"
         )
+
     """
 
     @cachedproperty
@@ -143,14 +137,11 @@ class SubredditRules:
 
             subreddit = await reddit.subreddit("NAME")
             await subreddit.rules.mod.add(
-                short_name="No spam",
-                kind="all",
-                description="Do not spam. Spam bad"
+                short_name="No spam", kind="all", description="Do not spam. Spam bad"
             )
 
-        To move the fourth rule to the first position, and then to move the
-        prior first rule to where the third rule originally was in the
-        subreddit ``"NAME"``:
+        To move the fourth rule to the first position, and then to move the prior first
+        rule to where the third rule originally was in the subreddit ``"NAME"``:
 
         .. code-block:: python
 
@@ -163,21 +154,22 @@ class SubredditRules:
         """
         return SubredditRulesModeration(self)
 
-    async def __call__(self) -> List[Rule]:
+    async def __call__(self) -> List["asyncpraw.models.Rule"]:
         r"""Return a list of :class:`.Rule`\ s (Deprecated).
 
         :returns: A list of instances of :class:`.Rule`.
 
         .. deprecated:: 7.1
 
-            Use the iterator by removing the call to :class:`.SubredditRules`.
-            For example, in order to use the iterator:
+            Use the iterator by removing the call to :class:`.SubredditRules`. For
+            example, in order to use the iterator:
 
             .. code-block:: python
 
                 subreddit = await reddit.subreddit("test")
                 async for rule in subreddit.rules:
                     print(rule)
+
         """
         warn(
             "Calling SubredditRules to get a list of rules is deprecated. Remove the"
@@ -191,7 +183,9 @@ class SubredditRules:
             "GET", API_PATH["rules"].format(subreddit=self.subreddit)
         )
 
-    async def get_rule(self, short_name: Union[str, int, slice]) -> Rule:
+    async def get_rule(
+        self, short_name: Union[str, int, slice]
+    ) -> "asyncpraw.models.Rule":
         """Return the Rule for the subreddit with short_name ``short_name``.
 
         :param short_name: The short_name of the rule, or the rule number.
@@ -207,15 +201,16 @@ class SubredditRules:
 
         You can also fetch a numbered rule of a subreddit.
 
-        Rule numbers start at ``0``, so the first rule is at index ``0``, and the
-        second rule is at index ``1``, and so on.
+        Rule numbers start at ``0``, so the first rule is at index ``0``, and the second
+        rule is at index ``1``, and so on.
 
-        :raises: :py:class:`IndexError` if a rule of a specific number does not
-            exist.
+        :raises: :py:class:`IndexError` if a rule of a specific number does not exist.
 
-        .. note:: You can use negative indexes, such as ``-1``, to get the last
-            rule. You can also use slices, to get a subset of rules, such as
-            the last three rules with ``get_rule(slice(-3, None))``.
+        .. note::
+
+            You can use negative indexes, such as ``-1``, to get the last rule. You can
+            also use slices, to get a subset of rules, such as the last three rules with
+            ``get_rule(slice(-3, None))``.
 
         For example, to fetch the second rule of ``AskReddit``:
 
@@ -232,7 +227,7 @@ class SubredditRules:
         await rule._fetch()
         return rule
 
-    def __init__(self, subreddit: "Subreddit"):
+    def __init__(self, subreddit: "asyncpraw.models.Subreddit"):
         """Create a SubredditRules instance.
 
         :param subreddit: The subreddit whose rules to work with.
@@ -241,7 +236,7 @@ class SubredditRules:
         self.subreddit = subreddit
         self._reddit = subreddit._reddit
 
-    async def __aiter__(self) -> AsyncIterator[Rule]:
+    async def __aiter__(self) -> AsyncIterator["asyncpraw.models.Rule"]:
         """Iterate through the rules of the subreddit.
 
         :returns: An asynchronous iterator containing all of the rules of a subreddit.
@@ -265,6 +260,7 @@ class SubredditRules:
         """Get a list of Rule objects.
 
         :returns: A list of instances of :class:`.Rule`.
+
         """
         rule_list = await self._reddit.get(
             API_PATH["rules"].format(subreddit=self.subreddit)
@@ -295,7 +291,7 @@ class RuleModeration:
 
     """
 
-    def __init__(self, rule: Rule):
+    def __init__(self, rule: "asyncpraw.models.Rule"):
         """Initialize the RuleModeration class."""
         self.rule = rule
 
@@ -323,16 +319,19 @@ class RuleModeration:
         kind: Optional[str] = None,
         short_name: Optional[str] = None,
         violation_reason: Optional[str] = None,
-    ) -> Rule:
+    ) -> "asyncpraw.models.Rule":
         """Update the rule from this subreddit.
 
-        .. note:: Existing values will be used for any unspecified arguments.
+        .. note::
+
+            Existing values will be used for any unspecified arguments.
 
         :param description: The new description for the rule. Can be empty.
-        :param kind: The kind of item that the rule applies to. One of
-            ``"link"``, ``"comment"``, or ``"all"``.
+        :param kind: The kind of item that the rule applies to. One of ``"link"``,
+            ``"comment"``, or ``"all"``.
         :param short_name: The name of the rule.
         :param violation_reason: The reason that is shown on the report menu.
+
         :returns: A Rule object containing the updated values.
 
         To update ``"No spam"`` from the subreddit ``"NAME"`` try:
@@ -372,14 +371,11 @@ class SubredditRulesModeration:
 
         subreddit = await reddit.subreddit("NAME")
         await subreddit.rules.mod.add(
-             short_name="No spam",
-             kind="all",
-             description="Do not spam. Spam bad"
+            short_name="No spam", kind="all", description="Do not spam. Spam bad"
         )
 
-    To move the fourth rule to the first position, and then to move the prior
-    first rule to where the third rule originally was in the subreddit
-    ``"NAME"``:
+    To move the fourth rule to the first position, and then to move the prior first rule
+    to where the third rule originally was in the subreddit ``"NAME"``:
 
     .. code-block:: python
 
@@ -401,16 +397,17 @@ class SubredditRulesModeration:
         kind: str,
         description: str = "",
         violation_reason: Optional[str] = None,
-    ) -> Rule:
+    ) -> "asyncpraw.models.Rule":
         """Add a removal reason to this subreddit.
 
         :param short_name: The name of the rule.
-        :param kind: The kind of item that the rule applies to. One of
-            ``"link"``, ``"comment"``, or ``"all"``.
+        :param kind: The kind of item that the rule applies to. One of ``"link"``,
+            ``"comment"``, or ``"all"``.
         :param description: The description for the rule. Optional.
-        :param violation_reason: The reason that is shown on the report menu.
-            If a violation reason is not specified, the short name will be used
-            as the violation reason.
+        :param violation_reason: The reason that is shown on the report menu. If a
+            violation reason is not specified, the short name will be used as the
+            violation reason.
+
         :returns: The Rule added.
 
         To add rule ``"No spam"`` to the subreddit ``"NAME"`` try:
@@ -419,9 +416,7 @@ class SubredditRulesModeration:
 
             subreddit = await reddit.subreddit("NAME")
             await subreddit.rules.mod.add(
-                short_name="No spam",
-                kind="all",
-                description="Do not spam. Spam bad"
+                short_name="No spam", kind="all", description="Do not spam. Spam bad"
             )
 
         """
@@ -441,16 +436,19 @@ class SubredditRulesModeration:
         new_rule.subreddit = self.subreddit_rules.subreddit
         return new_rule
 
-    async def reorder(self, rule_list: List[Rule]) -> List[Rule]:
+    async def reorder(
+        self, rule_list: List["asyncpraw.models.Rule"]
+    ) -> List["asyncpraw.models.Rule"]:
         """Reorder the rules of a subreddit.
 
-        :param rule_list: The list of rules, in the wanted order. Each index of
-            the list indicates the position of the rule.
+        :param rule_list: The list of rules, in the wanted order. Each index of the list
+            indicates the position of the rule.
+
         :returns: A list containing the rules in the specified order.
 
-        For example, to move the fourth rule to the first position, and then to
-        move the prior first rule to where the third rule originally was in the
-        subreddit ``"NAME"``:
+        For example, to move the fourth rule to the first position, and then to move the
+        prior first rule to where the third rule originally was in the subreddit
+        ``"NAME"``:
 
         .. code-block:: python
 
