@@ -17,13 +17,13 @@ from .redditor import Redditor
 from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import asyncpraw
 
 
 class SubmissionFlair:
     """Provide a set of functions pertaining to Submission flair."""
 
-    def __init__(self, submission: "Submission"):
+    def __init__(self, submission: "asyncpraw.models.Submission"):
         """Create a SubmissionFlair instance.
 
         :param submission: The submission associated with the flair functions.
@@ -55,19 +55,17 @@ class SubmissionFlair:
         """Select flair for submission.
 
         :param flair_template_id: The flair template to select. The possible
-            ``flair_template_id`` values can be discovered through
-            :meth:`.choices`.
-        :param text: If the template's ``flair_text_editable`` value is True,
-            this value will set a custom text (default: None).
+            ``flair_template_id`` values can be discovered through :meth:`.choices`.
+        :param text: If the template's ``flair_text_editable`` value is True, this value
+            will set a custom text (default: None).
 
-        For example, to select an arbitrary editable flair text (assuming there
-        is one) and set a custom value try:
+        For example, to select an arbitrary editable flair text (assuming there is one)
+        and set a custom value try:
 
         .. code-block:: python
 
             choices = await submission.flair.choices()
-            template_id = next(x for x in choices
-                              if x["flair_text_editable"])["flair_template_id"]
+            template_id = next(x for x in choices if x["flair_text_editable"])["flair_template_id"]
             await submission.flair.select(template_id, "my custom value")
 
         """
@@ -96,7 +94,7 @@ class SubmissionModeration(ThingModerationMixin):
 
     REMOVAL_MESSAGE_API = "removal_link_message"
 
-    def __init__(self, submission: "Submission"):
+    def __init__(self, submission: "asyncpraw.models.Submission"):
         """Create a SubmissionModeration instance.
 
         :param submission: The submission to moderate.
@@ -107,17 +105,16 @@ class SubmissionModeration(ThingModerationMixin):
     async def contest_mode(self, state: bool = True):
         """Set contest mode for the comments of this submission.
 
-        :param state: (boolean) True enables contest mode, False, disables
-            (default: True).
+        :param state: (boolean) True enables contest mode, False, disables (default:
+            True).
 
         Contest mode have the following effects:
 
-        * The comment thread will default to being sorted randomly.
-        * Replies to top-level comments will be hidden behind "[show replies]"
-          buttons.
-        * Scores will be hidden from non-moderators.
-        * Scores accessed through the API (mobile apps, bots) will be obscured to
-          "1" for non-moderators.
+        - The comment thread will default to being sorted randomly.
+        - Replies to top-level comments will be hidden behind "[show replies]" buttons.
+        - Scores will be hidden from non-moderators.
+        - Scores accessed through the API (mobile apps, bots) will be obscured to "1"
+          for non-moderators.
 
         Example usage:
 
@@ -144,8 +141,8 @@ class SubmissionModeration(ThingModerationMixin):
         :param css_class: The css class to associate with the flair html (default: "").
         :param flair_template_id: The flair template id to use when flairing (Optional).
 
-        This method can only be used by an authenticated user who is a
-        moderator of the Submission's Subreddit.
+        This method can only be used by an authenticated user who is a moderator of the
+        Submission's Subreddit.
 
         Example usage:
 
@@ -171,8 +168,8 @@ class SubmissionModeration(ThingModerationMixin):
     async def nsfw(self):
         """Mark as not safe for work.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
@@ -184,7 +181,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. seealso::
 
-             :meth:`~.sfw`
+            :meth:`~.sfw`
 
         """
         await self.thing._reddit.post(
@@ -194,10 +191,9 @@ class SubmissionModeration(ThingModerationMixin):
     async def set_original_content(self):
         """Mark as original content.
 
-        This method can be used by moderators of the subreddit that the
-        submission belongs to. If the subreddit has enabled the Original
-        Content beta feature in settings, then the submission's author
-        can use it as well.
+        This method can be used by moderators of the subreddit that the submission
+        belongs to. If the subreddit has enabled the Original Content beta feature in
+        settings, then the submission's author can use it as well.
 
         Example usage:
 
@@ -209,7 +205,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. seealso::
 
-             :meth:`.unset_original_content`
+            :meth:`.unset_original_content`
 
         """
         data = {
@@ -217,15 +213,15 @@ class SubmissionModeration(ThingModerationMixin):
             "fullname": self.thing.fullname,
             "should_set_oc": True,
             "executed": False,
-            "r": str(self.thing.subreddit),
+            "r": self.thing.subreddit,
         }
         await self.thing._reddit.post(API_PATH["set_original_content"], data=data)
 
     async def sfw(self):
         """Mark as safe for work.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
@@ -246,8 +242,8 @@ class SubmissionModeration(ThingModerationMixin):
     async def spoiler(self):
         """Indicate that the submission contains spoilers.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
@@ -268,18 +264,19 @@ class SubmissionModeration(ThingModerationMixin):
     async def sticky(self, state: bool = True, bottom: bool = True):
         """Set the submission's sticky state in its subreddit.
 
-        :param state: (boolean) True sets the sticky for the submission, false
-            unsets (default: True).
-        :param bottom: (boolean) When true, set the submission as the bottom
-            sticky. If no top sticky exists, this submission will become the
-            top sticky regardless (default: True).
+        :param state: (boolean) True sets the sticky for the submission, false unsets
+            (default: True).
+        :param bottom: (boolean) When true, set the submission as the bottom sticky. If
+            no top sticky exists, this submission will become the top sticky regardless
+            (default: True).
 
-        .. note:: When a submission is stickied two or more times, the Reddit
-            API responds with a 409 error that is raises as a ``Conflict`` by
-            asyncprawcore. The method suppresses these ``Conflict`` errors.
+        .. note::
 
-        This submission will replace the second stickied submission if one
-        exists.
+            When a submission is stickied two or more times, the Reddit API responds
+            with a 409 error that is raises as a ``Conflict`` by asyncprawcore. The
+            method suppresses these ``Conflict`` errors.
+
+        This submission will replace the second stickied submission if one exists.
 
         For example:
 
@@ -302,8 +299,8 @@ class SubmissionModeration(ThingModerationMixin):
     async def suggested_sort(self, sort: str = "blank"):
         """Set the suggested sort for the comments of the submission.
 
-        :param sort: Can be one of: confidence, top, new, controversial, old,
-            random, qa, blank (default: blank).
+        :param sort: Can be one of: confidence, top, new, controversial, old, random,
+            qa, blank (default: blank).
 
         """
         await self.thing._reddit.post(
@@ -314,10 +311,9 @@ class SubmissionModeration(ThingModerationMixin):
     async def unset_original_content(self):
         """Indicate that the submission is not original content.
 
-        This method can be used by moderators of the subreddit that the
-        submission belongs to. If the subreddit has enabled the Original
-        Content beta feature in settings, then the submission's author
-        can use it as well.
+        This method can be used by moderators of the subreddit that the submission
+        belongs to. If the subreddit has enabled the Original Content beta feature in
+        settings, then the submission's author can use it as well.
 
         Example usage:
 
@@ -337,15 +333,15 @@ class SubmissionModeration(ThingModerationMixin):
             "fullname": self.thing.fullname,
             "should_set_oc": False,
             "executed": False,
-            "r": str(self.thing.subreddit),
+            "r": self.thing.subreddit,
         }
         await self.thing._reddit.post(API_PATH["set_original_content"], data=data)
 
     async def unspoiler(self):
         """Indicate that the submission does not contain spoilers.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         For example:
 
@@ -370,58 +366,51 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    =========================== ===============================================
-    Attribute                   Description
-    =========================== ===============================================
-    ``author``                  Provides an instance of :class:`.Redditor`.
-    ``clicked``                 Whether or not the submission has been clicked
-                                by the client.
-    ``comments``                Provides an instance of
-                                :class:`.CommentForest`.
-    ``created_utc``             Time the submission was created, represented in
-                                `Unix Time`_.
-    ``distinguished``           Whether or not the submission is distinguished.
-    ``edited``                  Whether or not the submission has been edited.
-    ``id``                      ID of the submission.
-    ``is_original_content``     Whether or not the submission has been set
-                                as original content.
-    ``is_self``                 Whether or not the submission is a selfpost
-                                (text-only).
-    ``link_flair_template_id``  The link flair's ID, or None if not flaired.
-    ``link_flair_text``         The link flair's text content, or None if not
-                                flaired.
-    ``locked``                  Whether or not the submission has been locked.
-    ``name``                    Fullname of the submission.
-    ``num_comments``            The number of comments on the submission.
-    ``over_18``                 Whether or not the submission has been marked
-                                as NSFW.
-    ``permalink``               A permalink for the submission.
-    ``poll_data``               A :class:`.PollData` object representing the
-                                data of this submission, if it is a poll
-                                submission.
-    ``saved``                   Whether or not the submission is saved.
-    ``score``                   The number of upvotes for the submission.
-    ``selftext``                The submissions' selftext - an empty string if
-                                a link post.
-    ``spoiler``                 Whether or not the submission has been marked
-                                as a spoiler.
-    ``stickied``                Whether or not the submission is stickied.
-    ``subreddit``               Provides an instance of :class:`.Subreddit`.
-    ``title``                   The title of the submission.
-    ``upvote_ratio``            The percentage of upvotes from all votes on the
-                                submission.
-    ``url``                     The URL the submission links to, or the
-                                permalink if a selfpost.
-    =========================== ===============================================
+    ========================== =========================================================
+    Attribute                  Description
+    ========================== =========================================================
+    ``author``                 Provides an instance of :class:`.Redditor`.
+    ``clicked``                Whether or not the submission has been clicked by the
+                               client.
+    ``comments``               Provides an instance of :class:`.CommentForest`.
+    ``created_utc``            Time the submission was created, represented in `Unix
+                               Time`_.
+    ``distinguished``          Whether or not the submission is distinguished.
+    ``edited``                 Whether or not the submission has been edited.
+    ``id``                     ID of the submission.
+    ``is_original_content``    Whether or not the submission has been set as original
+                               content.
+    ``is_self``                Whether or not the submission is a selfpost (text-only).
+    ``link_flair_template_id`` The link flair's ID.
+    ``link_flair_text``        The link flair's text content, or None if not flaired.
+    ``locked``                 Whether or not the submission has been locked.
+    ``name``                   Fullname of the submission.
+    ``num_comments``           The number of comments on the submission.
+    ``over_18``                Whether or not the submission has been marked as NSFW.
+    ``permalink``              A permalink for the submission.
+    ``poll_data``              A :class:`.PollData` object representing the data of this
+                               submission, if it is a poll submission.
+    ``saved``                  Whether or not the submission is saved.
+    ``score``                  The number of upvotes for the submission.
+    ``selftext``               The submissions' selftext - an empty string if a link
+                               post.
+    ``spoiler``                Whether or not the submission has been marked as a
+                               spoiler.
+    ``stickied``               Whether or not the submission is stickied.
+    ``subreddit``              Provides an instance of :class:`.Subreddit`.
+    ``title``                  The title of the submission.
+    ``upvote_ratio``           The percentage of upvotes from all votes on the
+                               submission.
+    ``url``                    The URL the submission links to, or the permalink if a
+                               selfpost.
+    ========================== =========================================================
 
-
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
     """
 
@@ -431,13 +420,13 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def id_from_url(url: str) -> str:
         """Return the ID contained within a submission URL.
 
-        :param url: A url to a submission in one of the following formats (http
-            urls will also work):
+        :param url: A url to a submission in one of the following formats (http urls
+            will also work):
 
-            * https://redd.it/2gmzqe
-            * https://reddit.com/comments/2gmzqe/
-            * https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https/
-            * https://www.reddit.com/gallery/2gmzqe
+            - https://redd.it/2gmzqe
+            - https://reddit.com/comments/2gmzqe/
+            - https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https/
+            - https://www.reddit.com/gallery/2gmzqe
 
         :raises: :class:`.InvalidURL` if URL is not a valid submission URL.
 
@@ -471,8 +460,8 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     async def comments(self) -> CommentForest:
         """Provide an instance of :class:`.CommentForest`.
 
-        This attribute can be used, for example, to obtain a flat list of
-        comments, with any :class:`.MoreComments` removed:
+        This attribute can be used, for example, to obtain a flat list of comments, with
+        any :class:`.MoreComments` removed:
 
         .. code-block:: python
 
@@ -484,8 +473,8 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
                 ...
 
         Sort order and comment limit can be set with the ``comment_sort`` and
-        ``comment_limit`` attributes before comments are fetched, including
-        any call to :meth:`.replace_more`:
+        ``comment_limit`` attributes before comments are fetched, including any call to
+        :meth:`.replace_more`:
 
         .. code-block:: python
 
@@ -496,9 +485,10 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
                 # do stuff with comment
                 ...
 
-        .. note:: The appropriate values for ``comment_sort`` include
-           ``confidence``, ``controversial``, ``new``, ``old``, ``q&a``,
-           and ``top``
+        .. note::
+
+            The appropriate values for ``comment_sort`` include ``confidence``,
+            ``controversial``, ``new``, ``old``, ``q&a``, and ``top``
 
         See :ref:`extracting_comments` for more on working with a
         :class:`.CommentForest`.
@@ -513,12 +503,11 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def flair(self) -> SubmissionFlair:
         """Provide an instance of :class:`.SubmissionFlair`.
 
-        This attribute is used to work with flair as a regular user of the
-        subreddit the submission belongs to. Moderators can directly use
-        :meth:`.flair`.
+        This attribute is used to work with flair as a regular user of the subreddit the
+        submission belongs to. Moderators can directly use :meth:`.flair`.
 
-        For example, to select an arbitrary editable flair text (assuming there
-        is one) and set a custom value try:
+        For example, to select an arbitrary editable flair text (assuming there is one)
+        and set a custom value try:
 
         .. code-block:: python
 
@@ -555,7 +544,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "asyncpraw.Reddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         url: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
@@ -564,8 +553,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         :param reddit: An instance of :class:`~.Reddit`.
         :param id: A reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by
-            :meth:`~asyncpraw.models.Submission.id_from_url`.
+        :param url: A URL supported by :meth:`~asyncpraw.models.Submission.id_from_url`.
 
         Either ``id`` or ``url`` can be provided, but not both.
 
@@ -648,12 +636,13 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         data = {"links": self.fullname}
         await self._reddit.post(API_PATH["store_visits"], data=data)
 
-    async def hide(self, other_submissions: Optional[List["Submission"]] = None):
+    async def hide(
+        self, other_submissions: Optional[List["asyncpraw.models.Submission"]] = None
+    ):
         """Hide Submission.
 
-        :param other_submissions: When provided, additionally
-            hide this list of :class:`.Submission` instances
-            as part of a single request (default: None).
+        :param other_submissions: When provided, additionally hide this list of
+            :class:`.Submission` instances as part of a single request (default: None).
 
         Example usage:
 
@@ -670,12 +659,13 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         for submissions in self._chunk(other_submissions, 50):
             await self._reddit.post(API_PATH["hide"], data={"id": submissions})
 
-    async def unhide(self, other_submissions: Optional[List["Submission"]] = None):
+    async def unhide(
+        self, other_submissions: Optional[List["asyncpraw.models.Submission"]] = None
+    ):
         """Unhide Submission.
 
-        :param other_submissions: When provided, additionally
-            unhide this list of :class:`.Submission` instances
-            as part of a single request (default: None).
+        :param other_submissions: When provided, additionally unhide this list of
+            :class:`.Submission` instances as part of a single request (default: None).
 
         Example usage:
 
@@ -694,43 +684,44 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
     async def crosspost(
         self,
-        subreddit: "Subreddit",
+        subreddit: "asyncpraw.models.Subreddit",
         title: Optional[str] = None,
         send_replies: bool = True,
         flair_id: Optional[str] = None,
         flair_text: Optional[str] = None,
         nsfw: bool = False,
         spoiler: bool = False,
-    ) -> "Submission":
+    ) -> "asyncpraw.models.Submission":
         """Crosspost the submission to a subreddit.
 
         .. note::
+
             Be aware you have to be subscribed to the target subreddit.
 
-        :param subreddit: Name of the subreddit or :class:`~.Subreddit`
-            object to crosspost into.
-        :param title: Title of the submission. Will use this submission's
-            title if `None` (default: None).
+        :param subreddit: Name of the subreddit or :class:`~.Subreddit` object to
+            crosspost into.
+        :param title: Title of the submission. Will use this submission's title if
+            `None` (default: None).
         :param flair_id: The flair template to select (default: None).
-        :param flair_text: If the template's ``flair_text_editable`` value is
-            True, this value will set a custom text (default: None).
-        :param send_replies: When True, messages will be sent to the
-            submission author when comments are made to the submission
-            (default: True).
-        :param nsfw: Whether or not the submission should be marked NSFW
+        :param flair_text: If the template's ``flair_text_editable`` value is True, this
+            value will set a custom text (default: None).
+        :param send_replies: When True, messages will be sent to the submission author
+            when comments are made to the submission (default: True).
+        :param nsfw: Whether or not the submission should be marked NSFW (default:
+            False).
+        :param spoiler: Whether or not the submission should be marked as a spoiler
             (default: False).
-        :param spoiler: Whether or not the submission should be marked as
-            a spoiler (default: False).
-        :returns: A :class:`~.Submission` object for the newly created
-            submission.
+
+        :returns: A :class:`~.Submission` object for the newly created submission.
 
         Example usage:
 
         .. code-block:: python
 
             submission = await reddit.submission(id="5or86n")
-            cross_post = await submission.crosspost(subreddit="learnprogramming",
-                                              send_replies=False)
+            cross_post = await submission.crosspost(
+                subreddit="learnprogramming", send_replies=False
+            )
 
         .. seealso::
 
