@@ -1,5 +1,5 @@
 """Provide the Subreddits class."""
-from typing import AsyncIterator, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, AsyncIterator, Dict, List, Optional, Union
 from warnings import warn
 
 from ..const import API_PATH
@@ -8,6 +8,9 @@ from .base import AsyncPRAWBase
 from .listing.generator import ListingGenerator
 from .util import stream_generator
 
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import asyncpraw
+
 
 class Subreddits(AsyncPRAWBase):
     """Subreddits is a Listing class that provides various subreddit lists."""
@@ -18,17 +21,18 @@ class Subreddits(AsyncPRAWBase):
 
     def default(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for default subreddits.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(
             self._reddit, API_PATH["subreddits_default"], **generator_kwargs
         )
 
-    def gold(self, **generator_kwargs) -> AsyncIterator[Subreddit]:
+    def gold(self, **generator_kwargs) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Alias for :meth:`.premium` to maintain backwards compatibility."""
         warn(
             "`subreddits.gold` has be renamed to `subreddits.premium`.",
@@ -39,11 +43,12 @@ class Subreddits(AsyncPRAWBase):
 
     def premium(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for premium subreddits.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(
             self._reddit, API_PATH["subreddits_gold"], **generator_kwargs
@@ -51,11 +56,12 @@ class Subreddits(AsyncPRAWBase):
 
     def new(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for new subreddits.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(
             self._reddit, API_PATH["subreddits_new"], **generator_kwargs
@@ -63,11 +69,12 @@ class Subreddits(AsyncPRAWBase):
 
     def popular(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for popular subreddits.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(
             self._reddit, API_PATH["subreddits_popular"], **generator_kwargs
@@ -75,16 +82,16 @@ class Subreddits(AsyncPRAWBase):
 
     async def recommended(
         self,
-        subreddits: List[Union[str, Subreddit]],
-        omit_subreddits: Optional[List[Union[str, Subreddit]]] = None,
-    ) -> List[Subreddit]:
+        subreddits: List[Union[str, "asyncpraw.models.Subreddit"]],
+        omit_subreddits: Optional[
+            List[Union[str, "asyncpraw.models.Subreddit"]]
+        ] = None,
+    ) -> List["asyncpraw.models.Subreddit"]:
         """Return subreddits recommended for the given list of subreddits.
 
-        :param subreddits: A list of Subreddit instances and/or subreddit
-            names.
-        :param omit_subreddits: A list of Subreddit instances and/or subreddit
-            names to exclude from the results (Reddit's end may not work as
-            expected).
+        :param subreddits: A list of Subreddit instances and/or subreddit names.
+        :param omit_subreddits: A list of Subreddit instances and/or subreddit names to
+            exclude from the results (Reddit's end may not work as expected).
 
         """
         if not isinstance(subreddits, list):
@@ -101,7 +108,7 @@ class Subreddits(AsyncPRAWBase):
 
     def search(
         self, query: str, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` of subreddits matching ``query``.
 
         Subreddits are searched by both their title and description.
@@ -111,7 +118,9 @@ class Subreddits(AsyncPRAWBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        .. seealso:: :meth:`~.search_by_name` to search by subreddit names
+        .. seealso::
+
+            :meth:`~.search_by_name` to search by subreddit names
 
         """
         self._safely_add_arguments(generator_kwargs, "params", q=query)
@@ -121,7 +130,7 @@ class Subreddits(AsyncPRAWBase):
 
     async def search_by_name(
         self, query: str, include_nsfw: bool = True, exact: bool = False
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Return list of Subreddits whose names begin with ``query``.
 
         :param query: Search for subreddits beginning with this string.
@@ -138,7 +147,9 @@ class Subreddits(AsyncPRAWBase):
 
     async def search_by_topic(
         self, query: str
-    ) -> AsyncIterator[Subreddit]:  # pragma: no cover; TODO: not currently working
+    ) -> AsyncIterator[
+        "asyncpraw.models.Subreddit"
+    ]:  # pragma: no cover; TODO: not currently working
         """Return list of Subreddits whose topics match ``query``.
 
         :param query: Search for subreddits relevant to the search topic.
@@ -157,11 +168,11 @@ class Subreddits(AsyncPRAWBase):
 
     def stream(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> AsyncIterator[Subreddit]:
+    ) -> AsyncIterator["asyncpraw.models.Subreddit"]:
         """Yield new subreddits as they are created.
 
-        Subreddits are yielded oldest first. Up to 100 historical subreddits
-        will initially be returned.
+        Subreddits are yielded oldest first. Up to 100 historical subreddits will
+        initially be returned.
 
         Keyword arguments are passed to :func:`.stream_generator`.
 
