@@ -8,7 +8,7 @@ from .models.reddit.base import RedditBase
 from .util import snake_case_keys
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .. import Reddit
+    from ... import asyncpraw
 
 
 class Objector:
@@ -21,8 +21,9 @@ class Objector:
         """Convert JSON response into an error object.
 
         :param data: The dict to be converted.
-        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if
-            ``data`` doesn't fit this model.
+
+        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if ``data``
+            doesn't fit this model.
 
         """
         if isinstance(data, list):
@@ -46,7 +47,9 @@ class Objector:
         if error:
             raise error
 
-    def __init__(self, reddit: "Reddit", parsers: Optional[Dict[str, Any]] = None):
+    def __init__(
+        self, reddit: "asyncpraw.Reddit", parsers: Optional[Dict[str, Any]] = None
+    ):
         """Initialize an Objector instance.
 
         :param reddit: An instance of :class:`~.Reddit`.
@@ -59,6 +62,7 @@ class Objector:
         """Create RedditBase objects from dicts.
 
         :param data: The structured data, assumed to be a dict.
+
         :returns: An instance of :class:`~.RedditBase`.
 
         """
@@ -132,6 +136,9 @@ class Objector:
         elif "username" in data.keys():
             data["name"] = data.pop("username")
             parser = self.parsers[self._reddit.config.kinds["redditor"]]
+        elif {"mod_permissions", "name", "sr", "subscribers"}.issubset(data):
+            data["display_name"] = data["sr"]
+            parser = self.parsers[self._reddit.config.kinds["subreddit"]]
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
@@ -140,13 +147,14 @@ class Objector:
         return parser.parse(data, self._reddit)
 
     def objectify(
-        self, data: Optional[Union[Dict[str, Any], List[Any]]]
-    ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any]]]:
+        self, data: Optional[Union[Dict[str, Any], List[Any], bool]]
+    ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any], bool]]:
         """Create RedditBase objects from data.
 
         :param data: The structured data.
-        :returns: An instance of :class:`~.RedditBase`, or ``None`` if
-            given ``data`` is ``None``.
+
+        :returns: An instance of :class:`~.RedditBase`, or ``None`` if given ``data`` is
+            ``None``.
 
         """
         # pylint: disable=too-many-return-statements
@@ -154,6 +162,8 @@ class Objector:
             return None
         if isinstance(data, list):
             return [self.objectify(item) for item in data]
+        if isinstance(data, bool):  # Reddit.username_available
+            return data
         if "json" in data and "errors" in data["json"]:
             errors = data["json"]["errors"]
             if len(errors) > 0:
@@ -166,7 +176,10 @@ class Objector:
             return parser.parse(data, self._reddit)
         if {"kind", "data"}.issubset(data) and data["kind"] in self.parsers:
             parser = self.parsers[data["kind"]]
-            return parser.parse(data["data"], self._reddit)
+            if data["kind"] == "ModeratedList":
+                return parser.parse(data, self._reddit)
+            else:
+                return parser.parse(data["data"], self._reddit)
         if "json" in data and "data" in data["json"]:
             if "websocket_url" in data["json"]["data"]:
                 return data
