@@ -3,9 +3,20 @@ import asyncio
 import configparser
 import os
 import re
+from copy import copy
 from itertools import islice
 from logging import getLogger
-from typing import IO, Any, AsyncGenerator, Dict, Iterable, Optional, Type, Union
+from typing import (
+    IO,
+    TYPE_CHECKING,
+    Any,
+    AsyncGenerator,
+    Dict,
+    Iterable,
+    Optional,
+    Type,
+    Union,
+)
 from warnings import warn
 
 from asyncprawcore import (
@@ -30,6 +41,7 @@ from .exceptions import (
     RedditAPIException,
 )
 from .objector import Objector
+from .util.token_manager import BaseTokenManager
 
 try:
     from update_checker import update_check
@@ -38,6 +50,8 @@ try:
 except ImportError:  # pragma: no cover
     UPDATE_CHECKER_MISSING = True
 
+if TYPE_CHECKING:  # pragma: no cover
+    from .. import asyncpraw
 
 Comment = models.Comment
 Redditor = models.Redditor
@@ -50,16 +64,20 @@ logger = getLogger("asyncpraw")
 class Reddit:
     """The Reddit class provides convenient access to Reddit's API.
 
-    Instances of this class are the gateway to interacting with Reddit's API
-    through Async PRAW. The canonical way to obtain an instance of this class is via:
-
+    Instances of this class are the gateway to interacting with Reddit's API through
+    Async PRAW. The canonical way to obtain an instance of this class is via:
 
     .. code-block:: python
 
-       import asyncpraw
-       reddit = asyncpraw.Reddit(client_id="CLIENT_ID",
-                            client_secret="CLIENT_SECRET", password="PASSWORD",
-                            user_agent="USERAGENT", username="USERNAME")
+        import asyncpraw
+
+        reddit = asyncpraw.Reddit(
+            client_id="CLIENT_ID",
+            client_secret="CLIENT_SECRET",
+            password="PASSWORD",
+            user_agent="USERAGENT",
+            username="USERNAME",
+        )
 
     """
 
@@ -81,8 +99,8 @@ class Reddit:
     def read_only(self, value: bool) -> None:
         """Set or unset the use of the ReadOnlyAuthorizer.
 
-        :raises: :class:`ClientException` when attempting to unset ``read_only``
-            and only the ReadOnlyAuthorizer is available.
+        :raises: :class:`ClientException` when attempting to unset ``read_only`` and
+            only the ReadOnlyAuthorizer is available.
 
         """
         if value:
@@ -100,9 +118,8 @@ class Reddit:
 
         .. deprecated:: 7.0
 
-            If property :attr:`.validate_on_submit` is set to False, the
-            behavior is deprecated by Reddit. This attribute will be removed
-            around May-June 2020.
+            If property :attr:`.validate_on_submit` is set to False, the behavior is
+            deprecated by Reddit. This attribute will be removed around May-June 2020.
 
         """
         value = self._validate_on_submit
@@ -128,13 +145,22 @@ class Reddit:
         """Handle the context manager close."""
         await self.close()
 
+    def __deepcopy__(self, memodict={}):
+        """Shallow copy on deepcopy.
+
+        A shallow copied is performed on deepcopy as
+        :py:class:`asyncio.AbstractEventLoop` cannot be deepcopied.
+
+        """
+        return copy(self)
+
     def __enter__(self):
         """Handle the context manager open.
 
         .. deprecated:: 7.1.1
 
-            Using this class as a synchronous context manager is deprecated and will
-            be removed in the next release. Use this class as an asynchronous context
+            Using this class as a synchronous context manager is deprecated and will be
+            removed in the next release. Use this class as an asynchronous context
             manager instead.
 
         """
@@ -160,41 +186,47 @@ class Reddit:
         config_interpolation: Optional[str] = None,
         requestor_class: Optional[Type[Requestor]] = None,
         requestor_kwargs: Dict[str, Any] = None,
+        *,
+        token_manager: Optional[BaseTokenManager] = None,
         **config_settings: Union[str, bool],
     ):  # noqa: D207, D301
         """Initialize a Reddit instance.
 
-        :param site_name: The name of a section in your ``praw.ini`` file from
-            which to load settings from. This parameter, in tandem with an
-            appropriately configured ``praw.ini``, file is useful if you wish
-            to easily save credentials for different applications, or
-            communicate with other servers running Reddit. If ``site_name`` is
-            ``None``, then the site name will be looked for in the environment
-            variable praw_site. If it is not found there, the DEFAULT site will
-            be used.
-        :param requestor_class: A class that will be used to create a
-            requestor. If not set, use ``asyncprawcore.Requestor`` (default: None).
-        :param requestor_kwargs: Dictionary with additional keyword arguments
-            used to initialize the requestor (default: None).
+        :param site_name: The name of a section in your ``praw.ini`` file from which to
+            load settings from. This parameter, in tandem with an appropriately
+            configured ``praw.ini``, file is useful if you wish to easily save
+            credentials for different applications, or communicate with other servers
+            running Reddit. If ``site_name`` is ``None``, then the site name will be
+            looked for in the environment variable praw_site. If it is not found there,
+            the DEFAULT site will be used.
+        :param requestor_class: A class that will be used to create a requestor. If not
+            set, use ``asyncprawcore.Requestor`` (default: None).
+        :param requestor_kwargs: Dictionary with additional keyword arguments used to
+            initialize the requestor (default: None).
+        :param token_manager: When provided, the passed instance, a subclass of
+            :class:`.BaseTokenManager`, will manage tokens via two callback functions.
+            This parameter must be provided in order to work with refresh tokens
+            (default: None).
 
-        Additional keyword arguments will be used to initialize the
-        :class:`.Config` object. This can be used to specify configuration
-        settings during instantiation of the :class:`.Reddit` instance. For
-        more details please see :ref:`configuration`.
+        Additional keyword arguments will be used to initialize the :class:`.Config`
+        object. This can be used to specify configuration settings during instantiation
+        of the :class:`.Reddit` instance. For more details, please see
+        :ref:`configuration`.
 
         Required settings are:
 
-        * client_id
-        * client_secret (for installed applications set this value to ``None``)
-        * user_agent
+        - client_id
+        - client_secret (for installed applications set this value to ``None``)
+        - user_agent
 
-        The ``requestor_class`` and ``requestor_kwargs`` allow for
-        customization of the requestor :class:`.Reddit` will use. This allows,
-        e.g., easily adding behavior to the requestor or wrapping its
-        |ClientSession|_ in a caching layer. Example usage:
+        The ``requestor_class`` and ``requestor_kwargs`` allow for customization of the
+        requestor :class:`.Reddit` will use. This allows, e.g., easily adding behavior
+        to the requestor or wrapping its |ClientSession|_ in a caching layer. Example
+        usage:
 
         .. |ClientSession| replace:: ``ClientSession``
-        .. _ClientSession: https://docs.aiohttp.org/en/stable/client_advanced.html
+
+        .. _clientsession: https://docs.aiohttp.org/en/stable/client_advanced.html
 
         .. code-block:: python
 
@@ -212,9 +244,11 @@ class Reddit:
                     print(json.dumps(await response.json(), indent=4))
                     return response
 
+
             my_session = aiohttp.ClientSession(trust_env=True)
-            reddit = Reddit(..., requestor_class=JSONDebugRequestor,
-                            requestor_kwargs={"session": my_session})
+            reddit = Reddit(
+                ..., requestor_class=JSONDebugRequestor, requestor_kwargs={"session": my_session}
+            )
 
         You can automatically close the requestor session by using this class as an
         context manager:
@@ -237,6 +271,7 @@ class Reddit:
         """
         self._core = self._authorized_core = self._read_only_core = None
         self._objector = None
+        self._token_manager = token_manager
         self._unique_counter = 0
         self._validate_on_submit = False
 
@@ -280,8 +315,7 @@ class Reddit:
         self.auth = models.Auth(self, None)
         """An instance of :class:`.Auth`.
 
-        Provides the interface for interacting with installed and web
-        applications.
+        Provides the interface for interacting with installed and web applications.
 
         .. seealso::
 
@@ -292,8 +326,7 @@ class Reddit:
         self.front = models.Front(self)
         """An instance of :class:`.Front`.
 
-        Provides the interface for interacting with front page listings. For
-        example:
+        Provides the interface for interacting with front page listings. For example:
 
         .. code-block:: python
 
@@ -305,10 +338,9 @@ class Reddit:
         self.inbox = models.Inbox(self, None)
         """An instance of :class:`.Inbox`.
 
-        Provides the interface to a user's inbox which produces
-        :class:`.Message`, :class:`.Comment`, and :class:`.Submission`
-        instances. For example, to iterate through comments which mention the
-        authorized user run:
+        Provides the interface to a user's inbox which produces :class:`.Message`,
+        :class:`.Comment`, and :class:`.Submission` instances. For example, to iterate
+        through comments which mention the authorized user run:
 
         .. code-block:: python
 
@@ -320,8 +352,8 @@ class Reddit:
         self.live = models.LiveHelper(self, None)
         """An instance of :class:`.LiveHelper`.
 
-        Provides the interface for working with :class:`.LiveThread`
-        instances. At present only new LiveThreads can be created.
+        Provides the interface for working with :class:`.LiveThread` instances. At
+        present only new LiveThreads can be created.
 
         .. code-block:: python
 
@@ -332,9 +364,8 @@ class Reddit:
         self.multireddit = models.MultiredditHelper(self, None)
         """An instance of :class:`.MultiredditHelper`.
 
-        Provides the interface to working with :class:`.Multireddit`
-        instances. For example, you can obtain a :class:`.Multireddit` instance
-        via:
+        Provides the interface to working with :class:`.Multireddit` instances. For
+        example, you can obtain a :class:`.Multireddit` instance via:
 
         .. code-block:: python
 
@@ -351,8 +382,8 @@ class Reddit:
         self.redditors = models.Redditors(self, None)
         """An instance of :class:`.Redditors`.
 
-        Provides the interface for Redditor discovery. For example,
-        to iterate over the newest Redditors, run:
+        Provides the interface for Redditor discovery. For example, to iterate over the
+        newest Redditors, run:
 
         .. code-block:: python
 
@@ -364,8 +395,8 @@ class Reddit:
         self.subreddit = models.SubredditHelper(self, None)
         """An instance of :class:`.SubredditHelper`.
 
-        Provides the interface to working with :class:`.Subreddit`
-        instances. For example, to create a Subreddit run:
+        Provides the interface to working with :class:`.Subreddit` instances. For
+        example, to create a Subreddit run:
 
         .. code-block:: python
 
@@ -383,8 +414,8 @@ class Reddit:
 
             await reddit.subreddit("redditdev", fetch=True)
 
-        Multiple subreddits can be combined and filtered views of
-        r/all can also be used just like a subreddit:
+        Multiple subreddits can be combined and filtered views of r/all can also be used
+        just like a subreddit:
 
         .. code-block:: python
 
@@ -396,8 +427,8 @@ class Reddit:
         self.subreddits = models.Subreddits(self, None)
         """An instance of :class:`.Subreddits`.
 
-        Provides the interface for :class:`.Subreddit` discovery. For example,
-        to iterate over the set of default subreddits run:
+        Provides the interface for :class:`.Subreddit` discovery. For example, to
+        iterate over the set of default subreddits run:
 
         .. code-block:: python
 
@@ -409,9 +440,8 @@ class Reddit:
         self.user = models.User(self)
         """An instance of :class:`.User`.
 
-        Provides the interface to the currently authorized
-        :class:`.Redditor`. For example, to get the name of the current user
-        run:
+        Provides the interface to the currently authorized :class:`.Redditor`. For
+        example, to get the name of the current user run:
 
         .. code-block:: python
 
@@ -426,6 +456,29 @@ class Reddit:
             update_check(__package__, __version__)
             Reddit.update_checked = True
 
+    def _prepare_common_authorizer(self, authenticator):
+        if self._token_manager is not None:
+            if self.config._do_not_use_refresh_token != self.config.CONFIG_NOT_SET:
+                raise TypeError(
+                    "legacy ``refresh_token`` setting cannot be provided when providing"
+                    " ``token_manager``"
+                )
+
+            self._token_manager.reddit = self
+            authorizer = Authorizer(
+                authenticator,
+                post_refresh_callback=self._token_manager.post_refresh_callback,
+                pre_refresh_callback=self._token_manager.pre_refresh_callback,
+            )
+        elif self.config._do_not_use_refresh_token != self.config.CONFIG_NOT_SET:
+            authorizer = Authorizer(
+                authenticator, refresh_token=self.config._do_not_use_refresh_token
+            )
+        else:
+            self._core = self._read_only_core
+            return
+        self._core = self._authorized_core = session(authorizer)
+
     def _prepare_objector(self):
         mappings = {
             self.config.kinds["comment"]: models.Comment,
@@ -442,6 +495,7 @@ class Reddit:
             "LiveUpdate": models.LiveUpdate,
             "LiveUpdateEvent": models.LiveThread,
             "MenuLink": models.MenuLink,
+            "ModeratedList": models.ModeratedList,
             "ModmailAction": models.ModmailAction,
             "ModmailConversation": models.ModmailConversation,
             "ModmailMessage": models.ModmailMessage,
@@ -501,11 +555,8 @@ class Reddit:
                 authenticator, self.config.username, self.config.password
             )
             self._core = self._authorized_core = session(script_authorizer)
-        elif self.config.refresh_token:
-            authorizer = Authorizer(authenticator, self.config.refresh_token)
-            self._core = self._authorized_core = session(authorizer)
         else:
-            self._core = self._read_only_core
+            self._prepare_common_authorizer(authenticator)
 
     def _prepare_untrusted_asyncprawcore(self, requestor):
         authenticator = UntrustedAuthenticator(
@@ -513,11 +564,7 @@ class Reddit:
         )
         read_only_authorizer = DeviceIDAuthorizer(authenticator)
         self._read_only_core = session(read_only_authorizer)
-        if self.config.refresh_token:
-            authorizer = Authorizer(authenticator, self.config.refresh_token)
-            self._core = self._authorized_core = session(authorizer)
-        else:
-            self._core = self._read_only_core
+        self._prepare_common_authorizer(authenticator)
 
     async def comment(
         self,  # pylint: disable=invalid-name
@@ -525,23 +572,25 @@ class Reddit:
         url: Optional[str] = None,
         lazy: bool = False,
     ):
-        """Return an instance of :class:`~.Comment` for ``id``.
+        """Return an instance of :class:`~.Comment`.
 
         :param id: The ID of the comment.
         :param url: A permalink pointing to the comment.
         :param lazy: If True, object is loaded lazily (default: False).
 
-        If you don't need the object fetched right away (e.g., to utilize a
-        class method) then you can do:
+        If you don't need the object fetched right away (e.g., to utilize a class
+        method) then you can do:
 
         .. code-block:: python
 
             comment = await reddit.comment("comment_id", lazy=True)
             await comment.reply("reply")
 
-        .. note:: If call this with ``lazy=True`` and you need to obtain the
-                   comment's replies, you will need to call this without ``lazy=True``
-                   or call :meth:`~.Comment.refresh` on the returned :class:`.Comment`.
+        .. note::
+
+            If call this with ``lazy=True`` and you need to obtain the comment's
+            replies, you will need to call this without ``lazy=True`` or call
+            :meth:`~.Comment.refresh` on the returned :class:`.Comment`.
 
         """
         comment = models.Comment(self, id=id, url=url)
@@ -565,8 +614,7 @@ class Reddit:
         """Return parsed objects returned from a GET request to ``path``.
 
         :param path: The path to fetch.
-        :param params: The query parameters to add to the request (default:
-            None).
+        :param params: The query parameters to add to the request (default: None).
 
         """
         return await self._objectify_request(method="GET", params=params, path=path)
@@ -575,29 +623,39 @@ class Reddit:
         self,
         fullnames: Optional[Iterable[str]] = None,
         url: Optional[str] = None,
-        subreddits: Optional[Iterable[Union[Subreddit, str]]] = None,
-    ) -> AsyncGenerator[Union[Subreddit, Comment, Submission], None]:
+        subreddits: Optional[Iterable[Union["asyncpraw.models.Subreddit", str]]] = None,
+    ) -> AsyncGenerator[
+        Union[
+            "asyncpraw.models.Subreddit",
+            "asyncpraw.models.Comment",
+            "asyncpraw.models.Submission",
+        ],
+        None,
+    ]:
         """Fetch information about each item in ``fullnames``, ``url``, or ``subreddits``.
 
         :param fullnames: A list of fullnames for comments, submissions, and/or
             subreddits.
-        :param url: A url (as a string) to retrieve lists of link submissions
-            from.
+        :param url: A url (as a string) to retrieve lists of link submissions from.
         :param subreddits: A list of subreddit names or Subreddit objects to retrieve
             subreddits from.
+
         :returns: A generator that yields found items in their relative order.
 
-        Items that cannot be matched will not be generated. Requests will be
-        issued in batches for each 100 fullnames.
+        Items that cannot be matched will not be generated. Requests will be issued in
+        batches for each 100 fullnames.
 
-        .. note:: For comments that are retrieved via this method, if you want
-                  to obtain its replies, you will need to call
-                  :meth:`~.Comment.refresh` on the yielded :class:`.Comment`.
+        .. note::
 
-        .. note:: When using the URL option, it is important to be aware that
-                  URLs are treated literally by Reddit's API. As such, the URLs
-                  "youtube.com" and "https://www.youtube.com" will provide a
-                  different set of submissions.
+            For comments that are retrieved via this method, if you want to obtain its
+            replies, you will need to call :meth:`~.Comment.refresh` on the yielded
+            :class:`.Comment`.
+
+        .. note::
+
+            When using the URL option, it is important to be aware that URLs are treated
+            literally by Reddit's API. As such, the URLs "youtube.com" and
+            "https://www.youtube.com" will provide a different set of submissions.
 
         """
         none_count = (fullnames, url, subreddits).count(None)
@@ -617,11 +675,11 @@ class Reddit:
 
             api_parameter_name = "id" if is_using_fullnames else "sr_name"
 
-            async def generator(fullnames):
+            async def generator(names):
                 if is_using_fullnames:
-                    iterable = iter(ids_or_names)
+                    iterable = iter(names)
                 else:
-                    iterable = iter([str(item) for item in ids_or_names])
+                    iterable = iter([str(item) for item in names])
                 while True:
                     chunk = list(islice(iterable, 100))
                     if not chunk:
@@ -630,7 +688,7 @@ class Reddit:
                     for result in await self.get(API_PATH["info"], params=params):
                         yield result
 
-            return generator(fullnames)
+            return generator(ids_or_names)
 
         async def generator(url):
             params = {"url": url}
@@ -650,16 +708,15 @@ class Reddit:
     ) -> Any:
         """Run a request through the ``Objector``.
 
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param files: Dictionary, filename to file (like) object mapping
-            (default: None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
-        :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
-        :param params: The query parameters to add to the request (default:
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param files: Dictionary, filename to file (like) object mapping (default:
             None).
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
+        :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
+        :param params: The query parameters to add to the request (default: None).
         :param path: The path to fetch.
 
         """
@@ -699,11 +756,11 @@ class Reddit:
         """Return parsed objects returned from a DELETE request to ``path``.
 
         :param path: The path to fetch.
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
 
         """
         return await self._objectify_request(
@@ -719,11 +776,11 @@ class Reddit:
         """Return parsed objects returned from a PATCH request to ``path``.
 
         :param path: The path to fetch.
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
 
         """
         return await self._objectify_request(
@@ -741,15 +798,14 @@ class Reddit:
         """Return parsed objects returned from a POST request to ``path``.
 
         :param path: The path to fetch.
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param files: Dictionary, filename to file (like) object mapping
-            (default: None).
-        :param params: The query parameters to add to the request (default:
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param files: Dictionary, filename to file (like) object mapping (default:
             None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
+        :param params: The query parameters to add to the request (default: None).
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
 
         """
         if json is None:
@@ -786,22 +842,24 @@ class Reddit:
         """Return parsed objects returned from a PUT request to ``path``.
 
         :param path: The path to fetch.
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
 
         """
         return await self._objectify_request(
             data=data, json=json, method="PUT", path=path
         )
 
-    async def random_subreddit(self, nsfw: bool = False) -> Subreddit:
+    async def random_subreddit(
+        self, nsfw: bool = False
+    ) -> "asyncpraw.models.Subreddit":
         """Return a random instance of :class:`~.Subreddit`.
 
-        :param nsfw: Return a random NSFW (not safe for work) subreddit
-            (default: False).
+        :param nsfw: Return a random NSFW (not safe for work) subreddit (default:
+            False).
 
         """
         url = API_PATH["subreddit"].format(subreddit="randnsfw" if nsfw else "random")
@@ -819,8 +877,8 @@ class Reddit:
         name: Optional[str] = None,
         fullname: Optional[str] = None,
         fetch: bool = False,
-    ) -> Redditor:
-        """Return an instance of :class:`~.Redditor`.
+    ) -> "asyncpraw.models.Redditor":
+        """Return an instance of :class:`.Redditor`.
 
         :param name: The name of the redditor.
         :param fullname: The fullname of the redditor, starting with ``t2_``.
@@ -846,15 +904,14 @@ class Reddit:
 
         :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
         :param path: The path to fetch.
-        :param params: The query parameters to add to the request (default:
+        :param params: The query parameters to add to the request (default: None).
+        :param data: Dictionary, bytes, or file-like object to send in the body of the
+            request (default: None).
+        :param files: Dictionary, filename to file (like) object mapping (default:
             None).
-        :param data: Dictionary, bytes, or file-like object to send in the body
-            of the request (default: None).
-        :param files: Dictionary, filename to file (like) object mapping
-            (default: None).
-        :param json: JSON-serializable object to send in the body
-            of the request with a Content-Type header of application/json
-            (default: None). If ``json`` is provided, ``data`` should not be.
+        :param json: JSON-serializable object to send in the body of the request with a
+            Content-Type header of application/json (default: None). If ``json`` is
+            provided, ``data`` should not be.
 
         """
         if data and json:
@@ -871,38 +928,39 @@ class Reddit:
             )
         except BadRequest as exception:
             try:
-                data = await exception.response.json()
+                data = await exception.response.json(content_type=None)
             except ValueError:
-                # TODO: Remove this exception after 2020-12-31 if no one has
-                # filed a bug against it.
-                raise Exception(
-                    "Unexpected BadRequest without json body. Please file a bug at"
-                    " https://github.com/praw-dev/asyncpraw/issues"
-                ) from exception
+                text = await exception.response.text()
+                if text:
+                    data = {"reason": text}
+                else:
+                    raise exception
             if set(data) == {"error", "message"}:
                 raise
+            explanation = data.get("explanation")
             if "fields" in data:
                 assert len(data["fields"]) == 1
                 field = data["fields"][0]
             else:
                 field = None
             raise RedditAPIException(
-                [data["reason"], data["explanation"], field]
+                [data["reason"], explanation, field]
             ) from exception
 
     async def submission(  # pylint: disable=invalid-name,redefined-builtin
         self, id: Optional[str] = None, url: Optional[str] = None, lazy=False
-    ) -> Submission:
+    ) -> "asyncpraw.models.Submission":
         """Return an instance of :class:`~.Submission`.
 
         :param id: A Reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by :meth:`~asyncpraw.models.Submission.id_from_url`.`.
+        :param url: A URL supported by
+            :meth:`~asyncpraw.models.Submission.id_from_url`.`.
         :param lazy: If True, object is loaded lazily (default: False).
 
         Either ``id`` or ``url`` can be provided, but not both.
 
-        If you don't need the object fetched right away (e.g., to utilize a
-        class method) then you can do:
+        If you don't need the object fetched right away (e.g., to utilize a class
+        method) then you can do:
 
         .. code-block:: python
 
@@ -914,3 +972,17 @@ class Reddit:
         if not lazy:
             await submission._fetch()
         return submission
+
+    async def username_available(self, name: str) -> bool:
+        """Check to see if the username is available.
+
+        For example, to check if the username ``bboe`` is available, try:
+
+        .. code-block:: python
+
+            await reddit.username_available("bboe")
+
+        """
+        return await self._objectify_request(
+            path=API_PATH["username_available"], params={"user": name}, method="GET"
+        )
