@@ -4,12 +4,10 @@ import json
 import os
 from base64 import b64encode
 from datetime import datetime
-from functools import wraps
 
 import pytest
 from _pytest.tmpdir import _mk_tmp
 from vcr import VCR
-from vcr.cassette import Cassette
 from vcr.persisters.filesystem import FilesystemPersister
 from vcr.serialize import deserialize, serialize
 
@@ -49,46 +47,12 @@ def filter_access_token(response):
     return response
 
 
-placeholders = {
-    x: env_default(x)
-    for x in (
-        "auth_code client_id client_secret password redirect_uri test_subreddit"
-        " user_agent username refresh_token"
-    ).split()
-}
-
-placeholders["basic_auth"] = b64_string(
-    f"{placeholders['client_id']}:{placeholders['client_secret']}"
-)
-
-
-class CustomVCR(VCR):
-    """Derived from VCR to make setting paths easier."""
-
-    def use_cassette(self, path="", **kwargs):
-        """Use a cassette."""
-        path += ".json"
-        return super().use_cassette(path, **kwargs)
-
-
-def serialize_list(data: list):
-    new_list = []
-    for item in data:
-        if isinstance(item, dict):
-            new_list.append(serialize_dict(item))
-        elif isinstance(item, list):
-            new_list.append(serialize_list(item))
-        else:
-            new_list.append(item)
-    return new_list
-
-
 def serialize_dict(data: dict):
-    """this is to filter out buffered readers"""
+    """This is to filter out buffered readers."""
     new_dict = {}
     for key, value in data.items():
         if key == "file":
-            continue  # skip files
+            new_dict[key] = serialize_file(value.name)
         elif isinstance(value, dict):
             new_dict[key] = serialize_dict(value)
         elif isinstance(value, list):
@@ -98,17 +62,38 @@ def serialize_dict(data: dict):
     return new_dict
 
 
-class CustomSerializer(object):
-    @staticmethod
-    def serialize(cassette_dict):
-        cassette_dict["recorded_at"] = datetime.now().isoformat()[:-7]
-        return (
-            f"{json.dumps(serialize_dict(cassette_dict), sort_keys=True, indent=2)}\n"
-        )
+def serialize_file(file_name):
+    with open(file_name, "rb") as f:
+        return f.read().decode("utf-8", "replace")
 
-    @staticmethod
-    def deserialize(cassette_string):
-        return json.loads(cassette_string)
+
+def serialize_list(data: list):
+    new_list = []
+    for item in data:
+        if isinstance(item, dict):
+            new_list.append(serialize_dict(item))
+        elif isinstance(item, list):
+            new_list.append(serialize_list(item))
+        elif isinstance(item, tuple):
+            if item[0] == "file":
+                item = (item[0], serialize_file(item[1].name))
+            new_list.append(item)
+        else:
+            new_list.append(item)
+    return new_list
+
+
+placeholders = {
+    x: env_default(x)
+    for x in (
+        "auth_code client_id client_secret password redirect_uri test_subreddit"
+        " user_agent username"
+    ).split()
+}
+
+placeholders["basic_auth"] = b64_string(
+    f"{placeholders['client_id']}:{placeholders['client_secret']}"
+)
 
 
 class CustomPersister(FilesystemPersister):
@@ -140,6 +125,28 @@ class CustomPersister(FilesystemPersister):
             f.write(data)
 
 
+class CustomSerializer(object):
+    @staticmethod
+    def serialize(cassette_dict):
+        cassette_dict["recorded_at"] = datetime.now().isoformat()[:-7]
+        return (
+            f"{json.dumps(serialize_dict(cassette_dict), sort_keys=True, indent=2)}\n"
+        )
+
+    @staticmethod
+    def deserialize(cassette_string):
+        return json.loads(cassette_string)
+
+
+class CustomVCR(VCR):
+    """Derived from VCR to make setting paths easier."""
+
+    def use_cassette(self, path="", **kwargs):
+        """Use a cassette."""
+        path += ".json"
+        return super().use_cassette(path, **kwargs)
+
+
 VCR = CustomVCR(
     serializer="custom_serializer",
     cassette_library_dir="tests/integration/cassettes",
@@ -150,29 +157,6 @@ VCR.register_serializer("custom_serializer", CustomSerializer)
 VCR.register_persister(CustomPersister)
 
 
-def after_init(func, *args):
-    func(*args)
-
-
-def add_init_hook(original_init):
-    """Wrap an __init__ method to also call some hooks."""
-
-    @wraps(original_init)
-    def wrapper(self, *args, **kwargs):
-        original_init(self, *args, **kwargs)
-        after_init(init_hook, self)
-
-    return wrapper
-
-
-Cassette.__init__ = add_init_hook(Cassette.__init__)
-
-
-def init_hook(cassette):
-    if not cassette.requests:
-        pytest.set_up_record()  # dynamically defined in __init__.py
-
-
 class Placeholders:
     def __init__(self, _dict):
         self.__dict__ = _dict
@@ -184,5 +168,6 @@ def pytest_configure():
 
 @pytest.fixture
 def tmp_path(request, tmp_path_factory):
-    """Manually create tmp_path fixture since asynctest does not play nicely with fixtures as args"""
+    # Manually create tmp_path fixture since asynctest does not play nicely with
+    # fixtures as args
     request.cls.tmp_path = _mk_tmp(request, tmp_path_factory)
