@@ -1,8 +1,7 @@
 """Test classes from collections.py."""
 
-from asynctest import mock
-
 import pytest
+from asynctest import mock
 
 from asyncpraw.exceptions import ClientException
 from asyncpraw.models import Submission
@@ -81,7 +80,7 @@ class TestCollectionModeration(IntegrationTest):
             # Testing different types for _post_fullname
             await collection.mod.add_post(posts[0])  # Subreddit object
             await collection.mod.add_post(posts[1].fullname)  # fullname
-            await collection.mod.add_post("https://reddit.com" + posts[2].permalink)
+            await collection.mod.add_post(f"https://reddit.com{posts[2].permalink}")
             await collection.mod.add_post(posts[3].id)  # id
 
             posts.append(
