@@ -5,6 +5,7 @@ import pytest
 from asyncpraw import Reddit
 from asyncpraw.exceptions import APIException, AsyncPRAWException, WebSocketException
 from asyncpraw.models import Subreddit
+from asyncpraw.models.reddit.user_subreddit import UserSubreddit
 
 from . import UnitTest
 
@@ -78,6 +79,10 @@ class TestDeprecation(UnitTest):
             await submission.gild()
             assert excinfo.value.args[0] == "`.gild` has been renamed to `.award`."
 
+    async def test_reddit_user_me_read_only(self):
+        with pytest.raises(DeprecationWarning):
+            await self.reddit.user.me()
+
     def test_synchronous_context_manager(self):
         with pytest.raises(DeprecationWarning) as excinfo:
             with self.reddit:
@@ -86,3 +91,28 @@ class TestDeprecation(UnitTest):
                 excinfo.value.args[0]
                 == "Using this class as a synchronous context manager is deprecated and will be removed in the next release. Use this class as an asynchronous context manager instead."
             )
+
+    def test_reddit_refresh_token(self):
+        with pytest.raises(DeprecationWarning):
+            Reddit(
+                client_id="dummy",
+                client_secret=None,
+                redirect_uri="dummy",
+                refresh_token="dummy",
+                user_agent="dummy",
+            )
+
+    def test_user_subreddit_as_dict(self):
+        user_subreddit = UserSubreddit(None, display_name="test")
+        with pytest.deprecated_call() as warning_info:
+            display_name = user_subreddit["display_name"]
+            assert display_name == "test"
+            assert (
+                warning_info.list[0].message.args[0]
+                == "`Redditor.subreddit` is no longer a dict and is now an `UserSubreddit` object. Accessing attributes using string indices is deprecated."
+            )
+            assert user_subreddit.keys() == user_subreddit.__dict__.keys()
+            assert (
+                warning_info.list[1].message.args[0]
+                == "`Redditor.subreddit` is no longer a dict and is now an `UserSubreddit` object. Using `keys` is deprecated and will be removed in Async PRAW 8."
+            )
